@@ -1,15 +1,15 @@
 // AbbreviationsDlg.h
-// (c) 2004 exeal
+// (c) 2004-2005 exeal
 
 #ifndef _ABBREVIATIONS_DLG_H_
 #define _ABBREVIATIONS_DLG_H_
-#include "..\Manah\Dialog.h"
+#include "../Manah/Dialog.h"
 
 
 namespace Alpha {
 
 ///	[Zk̊Ǘ] _CAO
-class CAbbreviationsDlg : public Manah::Windows::Controls::CDialog {
+class CAbbreviationsDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_ABBREVIATIONS> {
 	// \bh
 private:
 	void	Update();
@@ -22,7 +22,7 @@ protected:
 
 	// NX
 private:
-	class CNewAbbreviationDlg : public Manah::Windows::Controls::CDialog {
+	class CNewAbbreviationDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_NEWABBREV> {
 		// f[^o
 	public:
 		wchar_t	m_wszAbbreviation[1000];
