@@ -1,15 +1,16 @@
 // AboutDlg.h
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _ABOUT_DLG_H_
 #define _ABOUT_DLG_H_
-#include "..\Manah\Dialog.h"
-#include "..\Manah\LinkLabel.h"
+#include "resource.h"
+#include "../Manah/Dialog.h"
+#include "../Manah/LinkLabel.h"
 
 
 namespace Alpha {
 	///	uo[Wv_CAO
-	class CAboutDlg : public Manah::Windows::Controls::CDialog {
+	class CAboutDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_ABOUT> {
 		// f[^o
 	private:
 		Manah::Windows::Controls::CLinkLabel	m_homePageLink;
