@@ -1,5 +1,5 @@
 // AlphaDoc.h
-// (c) 2003 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _ALPHA_DOC_H_
 #define _ALPHA_DOC_H_
@@ -11,8 +11,9 @@
 namespace Alpha {
 	class CAlphaApp;
 	class CAlphaView;
-	class CAlphaEditController;
-
+	namespace Ambient {
+		class CBuffer;
+	}
 /*
 	///	u[N|Cg̏
 	enum BreakPointState {
@@ -41,25 +42,22 @@ namespace Alpha {
 	class CAlphaDoc : public Ascension::CEditDoc {
 		// RXgN^
 	public:
-		CAlphaDoc(CAlphaEditController* pController = 0);
+		CAlphaDoc();
 		virtual ~CAlphaDoc();
 
 		// \bh
 	public:
-		void					GetAutomation(CAlphaApp& app, IDocument** ppDocument);
-		CAlphaEditController*	GetController() const;
+		CAlphaView&		GetActiveView() const throw(std::logic_error);
+		HRESULT			GetAutomation(CAlphaApp& app, IBuffer** ppBuffer) const;
+		const TCHAR*	GetFileName() const;
+		CAlphaView&		GetView(std::size_t iView) const throw(std::out_of_range);
 
 		// f[^o
 	protected:
-		IDocument*	m_pAutomation;	// I[g[VpC^[tFCX
+		Ambient::CBuffer*	m_pAutomation;	// I[g[VpC^[tFCX
 	public:
 		std::wstring	m_strDocType;	// KpĂ镶^Cv
 	};
-
-	inline CAlphaEditController* CAlphaDoc::GetController() const {
-		AssertValid();
-		return reinterpret_cast<CAlphaEditController*>(m_pController);
-	}
 }
 
 #endif /* _ALPHA_EDIT_H_ */
