@@ -6,9 +6,6 @@
 
 
 namespace Alpha {
-	///	R}h̎ʎq ()
-	typedef WORD	CommandId;	// typeof(ACCEL::cmd)
-
 	///	ۑ\ȃIuWFNg
 	///	@see	CKeyboardMap
 	interface ISerializable {
