@@ -1,12 +1,11 @@
 // AlphaScriptHost.cpp
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #include "StdAfx.h"
 #include "AlphaScriptHost.h"
 #include <objsafe.h>	// IObjectSafety
 using Alpha::CAlphaScriptHost;
 using Alpha::ScriptSiteSecurityLevel;
-using Alpha::CEnumImpl;
 using namespace std;
 using namespace Armaiti;
 
@@ -42,28 +41,26 @@ namespace {
 		LCID		lcid;				///< LCID
 		IStream**	ppObjectArguments;	///< pArguments ̃}[VOꂽA̔z
 	};
-}
+} // namespace `anonymous'
 
 
 // CAlphaScriptHost class implementation
 /////////////////////////////////////////////////////////////////////////////
 
-const wchar_t* 			CAlphaScriptHost::m_pwszName = L"Alpha Script Host";
-const unsigned short	CAlphaScriptHost::m_nMajorVersion = 0;	///< W[o[W
-const unsigned short	CAlphaScriptHost::m_nMinorVersion = 6;	///< }Ci[o[W
-const unsigned short	CAlphaScriptHost::m_nBuildVersion = 2;	///< rhԍ
+const wchar_t* 			CAlphaScriptHost::m_pwszName = L"Alpha Script Host";	///< XNvgzXg̖O
+const unsigned short	CAlphaScriptHost::m_nMajorVersion = 0;					///< W[o[W
+const unsigned short	CAlphaScriptHost::m_nMinorVersion = 6;					///< }Ci[o[W
+const unsigned short	CAlphaScriptHost::m_nBuildVersion = 601;				///< rhԍ
 
 /**
  *	RXgN^
- *	@param hWnd							TCgEBhE
- *	@param pScriptEngine				GW
- *	@param bIgnoreCaseOnPropertySearch	vpeBTɑ啶ʂȂ
+ *	@param hWnd				TCgEBhE
+ *	@param pScriptEngine	GW
  */
-CAlphaScriptHost::CAlphaScriptHost(HWND hWnd, IActiveScript* pScriptEngine, bool bIgnoreCaseOnPropertySearch)
+CAlphaScriptHost::CAlphaScriptHost(HWND hWnd, IActiveScript* pScriptEngine)
 		: m_hOwnerWindow(hWnd), m_pScriptEngine(pScriptEngine),
-		m_nSecurityLevelForSafeObject(SSSL_ALLOW), m_nSecurityLevelForUnsafeObject(SSSL_QUERYUSER),
-		m_bAllowedErrorReport(true), m_bIgnoreCaseOnPropertySearch(bIgnoreCaseOnPropertySearch),
-		m_bEnteredScript(false), m_bInteractive(true), m_nTimeout(0) {
+		m_securityLevelForSafeObject(SSSL_ALLOW), m_securityLevelForUnsafeObject(SSSL_QUERYUSER),
+		m_bAllowedErrorReport(true), m_bEnteredScript(false), m_bInteractive(true), m_nTimeout(0) {
 	assert(m_hOwnerWindow == 0 || ::IsWindow(m_hOwnerWindow));
 	assert(m_pScriptEngine != 0);
 
@@ -79,8 +76,8 @@ CAlphaScriptHost::CAlphaScriptHost(HWND hWnd, IActiveScript* pScriptEngine, bool
 			if(toBoolean(dwSupportedOpts & INTERFACE_USES_SECURITY_MANAGER))
 				pObjectSafety->SetInterfaceSafetyOptions(IID_NULL, dwSupportedOpts, INTERFACE_USES_SECURITY_MANAGER);
 			else {
-				SetSecurityLevel(true, m_nSecurityLevelForSafeObject);
-				SetSecurityLevel(false, m_nSecurityLevelForUnsafeObject);
+				SetSecurityLevel(true, m_securityLevelForSafeObject);
+				SetSecurityLevel(false, m_securityLevelForUnsafeObject);
 			}
 		}
 	}
@@ -89,10 +86,9 @@ CAlphaScriptHost::CAlphaScriptHost(HWND hWnd, IActiveScript* pScriptEngine, bool
 ///	fXgN^
 CAlphaScriptHost::~CAlphaScriptHost() {
 	for(EventSinkTable::iterator it = m_eventSinks.begin(); it != m_eventSinks.end(); ++it)
-		DisconnectObject(it->first);
-	m_pScriptEngine->Close();
-	m_pScriptEngine->Release();
-	_ReleaseTopLevelObjects();
+		DisconnectObject(*it->first);
+	ReleaseTopLevelObjects();
+	ReleaseScriptEngine();
 }
 
 /**
@@ -101,31 +97,88 @@ CAlphaScriptHost::~CAlphaScriptHost() {
  *	@param pObject					ŏʃIuWFNg
  *	@param dwItemTraits				IActiveScript::AddNamedItem Ɠ
  *	@throw std::invalid_argument	ɓ̃IuWFNg݂ꍇ
+ *	@throw std::logic_error			ɌGWꍇ
  */
 void CAlphaScriptHost::AddTopLevelObject(const OLECHAR* pwszObjectName, IDispatch* pObject, DWORD dwItemTraits) {
 	assert(pwszObjectName != 0);
 	assert(pObject != 0);
 
-	if(!m_bIgnoreCaseOnPropertySearch)
-		m_topLevelObjects[pwszObjectName] = pObject;
-	else {
-		wchar_t*	pwsz = new wchar_t[wcslen(pwszObjectName) + 1];
-		wcscpy(pwsz, pwszObjectName);
-		m_topLevelObjects[::CharLowerW(pwsz)] = pObject;
-		delete[] pwsz;
-	}
+	if(m_pScriptEngine == 0)
+		throw logic_error("Host is not bound to script engine.");
+
+	wchar_t* const	pwsz = new wchar_t[wcslen(pwszObjectName) + 1];
+
+	wcscpy(pwsz, pwszObjectName);
+	::CharLowerW(pwsz);
+	if(m_topLevelObjects.find(pwsz) != m_topLevelObjects.end())
+		throw invalid_argument("There is already same name object.");
+	m_topLevelObjects.insert(make_pair(pwsz, pObject));
+	delete[] pwsz;
 	pObject->AddRef();
 	m_pScriptEngine->AddNamedItem(pwszObjectName, dwItemTraits);
 }
 
+/**
+ *	֐Ăяo
+ *	@param function		֐
+ *	@param lcid			P[ʎq
+ *	@param pParams		 (svȏꍇ null)
+ *	@param pResult		[out] ߂l (svȏꍇ null)
+ *	@param pException	[out] O (svȏꍇ null)
+ *	@return				IDispatch::Invoke ̖߂l
+ */
+HRESULT CAlphaScriptHost::CallFunction(IDispatch& function,
+		LCID lcid /* = LOCALE_USER_DEFAULT */, DISPPARAMS* pParams /* = 0 */,
+		VARIANT* pResult /* = 0 */, EXCEPINFO* pException /* = 0 */) {
+	DISPPARAMS	emptyParams = {0, 0, 0, 0};
+	return function.Invoke(DISPID_VALUE, IID_NULL, lcid,
+		DISPATCH_METHOD, (pParams != 0) ? pParams : &emptyParams, pResult, pException, 0);
+}
+
+#ifdef __IDispatchEx_INTERFACE_DEFINED__
+/**
+ *	this tĊ֐Ăяo (Ot͖T|[g)
+ *	@param function		֐
+ *	@param thisArg		this 
+ *	@param lcid			P[ʎq
+ *	@param pParams		 (svȏꍇ null)
+ *	@param pResult		[out] ߂l (svȏꍇ null)
+ *	@param pException	[out] O (svȏꍇ null)
+ *	@return				IDispatchEx::InvokeEx ̖߂l
+ */
+HRESULT CallFunction(IDispatchEx& function, IDispatch& thisArg,
+		LCID lcid /* = LOCALE_USER_DEFAULT */, DISPPARAMS* pParams /* = 0 */,
+		VARIANT* pResult /* = 0 */, EXCEPINFO* pException /* = 0 */) {
+	DISPPARAMS	params = {0, 0, 0, 0};
+	VARIANTARG	thisParam;
+	DISPID		id = DISPID_THIS;
+
+	params.cArgs = (pParams != 0) ? pParams->cArgs + 1 : 1;
+	params.cNamedArgs = 1;
+	params.rgvarg = new VARIANTARG[params.cArgs];
+	params.rgvarg[0].vt = VT_DISPATCH;
+	params.rgvarg[0].pdispVal = &thisArg;
+	params.rgvarg[0].pdispVal->AddRef();
+	params.rgdispidNamedArgs = &id;
+	if(pParams != 0) {
+		for(int i = 0; i < params.cArgs; ++i)
+			params.rgvarg[i + 1] = pParams->rgvars[i];
+	}
+
+	const HRESULT	hr = pFunction->InvokeEx(DISPID_VALUE, lcid, DISPATCH_METHOD, &params, pResult, pException, 0);
+	arg.pdispVal->Release();
+	return hr;
+}
+#endif /* __IDispatchEx_INTERFACE_DEFINED__ */
+
 /**
  *
- *	@param pObject		ڑmIuWFNg
+ *	@param object		ڑmIuWFNg
  *	@param pwszPrefix	Cxgnh̐ړ
  *	@return				SCODE
  */
-HRESULT CAlphaScriptHost::ConnectObject(IDispatch* pObject, const OLECHAR* pwszPrefix) {
-	assert(pObject != 0 && pwszPrefix != 0);
+HRESULT CAlphaScriptHost::ConnectObject(IDispatch& object, const OLECHAR* pwszPrefix) {
+	assert(pwszPrefix != 0);
 
 	HRESULT								hr;
 	CComPtr<IConnectionPointContainer>	pCPContainer;
@@ -135,9 +188,9 @@ HRESULT CAlphaScriptHost::ConnectObject(IDispatch* pObject, const OLECHAR* pwszP
 	IID									iidEvent;
 
 	// ڑ|CgT
-	if(FAILED(pObject->QueryInterface(IID_IConnectionPointContainer, reinterpret_cast<void**>(&pCPContainer))))
+	if(FAILED(object.QueryInterface(IID_IConnectionPointContainer, reinterpret_cast<void**>(&pCPContainer))))
 		return E_NOINTERFACE;
-	if(S_OK == pObject->QueryInterface(
+	if(S_OK == object.QueryInterface(
 			IID_IProvideClassInfo2, reinterpret_cast<void**>(&pClassInfoProvider))) {
 		// IProvideClassInfo2::GetGUID Ŏ擾łꍇ
 		if(FAILED(hr = pClassInfoProvider->GetGUID(GUIDKIND_DEFAULT_SOURCE_DISP_IID, &iidEvent)))
@@ -154,15 +207,15 @@ HRESULT CAlphaScriptHost::ConnectObject(IDispatch* pObject, const OLECHAR* pwszP
 	if(pConnectionPoint == 0)
 		return E_FAIL/*CONNECT_E_CANNOTCONNECT*/;
 
-	CAdhocEventSink*	pSink = new CAdhocEventSink(*m_pScriptEngine, iidEvent, pwszPrefix);
-	pObject->AddRef();
+	_CAdhocEventSink*	pSink = new _CAdhocEventSink(*m_pScriptEngine, iidEvent, pwszPrefix);
+	object.AddRef();
 	pSink->AddRef();
-	m_eventSinks.insert(make_pair(pObject, pSink));
-	hr = pSink->Connect(pConnectionPoint);
+	m_eventSinks.insert(make_pair(&object, pSink));
+	hr = pSink->Connect(*pConnectionPoint);
 
 	if(FAILED(hr)) {
-		m_eventSinks.erase(pObject);
-		pObject->Release();
+		m_eventSinks.erase(&object);
+		object.Release();
 		pSink->Release();
 	}
 	return hr;
@@ -170,13 +223,11 @@ HRESULT CAlphaScriptHost::ConnectObject(IDispatch* pObject, const OLECHAR* pwszP
 
 /**
  *	
- *	@param pObject	ڑIuWFNg
+ *	@param object	ڑIuWFNg
  *	@return			SCODE
  */
-HRESULT CAlphaScriptHost::DisconnectObject(IDispatch* pObject) {
-	assert(pObject != 0);
-	
-	EventSinkTable::iterator	it = m_eventSinks.find(pObject);
+HRESULT CAlphaScriptHost::DisconnectObject(IDispatch& object) {
+	EventSinkTable::iterator	it = m_eventSinks.find(&object);
 
 	if(it == m_eventSinks.end())
 		return E_INVALIDARG;
@@ -253,13 +304,11 @@ STDMETHODIMP CAlphaScriptHost::GetItemInfo(LPCOLESTR pstrName,
 	IDispatch*	pItemObject = 0;
 	wchar_t*	pwsz = const_cast<OLECHAR*>(pstrName);
 
-	if(m_bIgnoreCaseOnPropertySearch) {
-		if(pwsz = new wchar_t[wcslen(pstrName) + 1]) {
-			wcscpy(pwsz, pstrName);
-			::CharLowerW(pwsz);
-		} else
-			return E_OUTOFMEMORY;
-	}
+	if(pwsz = new wchar_t[wcslen(pstrName) + 1]) {
+		wcscpy(pwsz, pstrName);
+		::CharLowerW(pwsz);
+	} else
+		return E_OUTOFMEMORY;
 
 	MemberTable::const_iterator	it = m_topLevelObjects.find(pwsz);
 
@@ -274,8 +323,7 @@ STDMETHODIMP CAlphaScriptHost::GetItemInfo(LPCOLESTR pstrName,
 			VERIFY_POINTER(ppTypeInfo);
 			*ppTypeInfo = 0;
 		}
-		if(m_bIgnoreCaseOnPropertySearch)
-			delete[] pwsz;
+		delete[] pwsz;
 		return TYPE_E_ELEMENTNOTFOUND;
 	}
 
@@ -288,8 +336,7 @@ STDMETHODIMP CAlphaScriptHost::GetItemInfo(LPCOLESTR pstrName,
 		pItemObject->GetTypeInfo(0, 0, ppTypeInfo);
 	}
 
-	if(m_bIgnoreCaseOnPropertySearch)
-		delete[] pwsz;
+	delete[] pwsz;
 	return S_OK;
 }
 
@@ -327,6 +374,73 @@ HRESULT CAlphaScriptHost::_InvokeScriptGlobalProcedure(const OLECHAR* pwszName,
 	return hr;
 }
 
+/**
+ *	^Cu (萔) ǂݍ
+ *
+ *	@param typeLib	^Cu
+ *	@param guid		ǂݍޗ񋓂 GUIDBȗƃCȗSĂ̗񋓂ǂݍ
+ *	@return			
+ */
+bool CAlphaScriptHost::LoadConstants(ITypeLib& typeLib, GUID guid /* = GUID_NULL */) {
+	const UINT	cTypeInfos = typeLib.GetTypeInfoCount();
+	bool		bLoadedOnce = false;
+
+	for(UINT i = 0; i < cTypeInfos; ++i) {
+		CComPtr<ITypeInfo>	pTypeInfo;
+		TYPEATTR*			pTypeAttr;
+
+		if(FAILED(typeLib.GetTypeInfo(i, &pTypeInfo)))
+			continue;
+		if(FAILED(pTypeInfo->GetTypeAttr(&pTypeAttr)))
+			continue;
+		if((guid != GUID_NULL && pTypeAttr->guid != guid) || pTypeAttr->typekind != TKIND_ENUM) {
+			pTypeInfo->ReleaseTypeAttr(pTypeAttr);
+			continue;
+		}
+
+		_CEnumImpl*	pEnum = new _CEnumImpl;
+		bool		bAddedOnce = false;
+
+		pEnum->AddRef();
+		for(WORD j = 0; j < pTypeAttr->cVars; ++j) {
+			VARDESC*	pVarDesc;
+
+			if(FAILED(pTypeInfo->GetVarDesc(j, &pVarDesc)))
+				continue;
+			if(pVarDesc->varkind != VAR_CONST
+					|| toBoolean(pVarDesc->wVarFlags & VARFLAG_FHIDDEN)
+					|| toBoolean(pVarDesc->wVarFlags & VARFLAG_FNONBROWSABLE)
+					|| toBoolean(pVarDesc->wVarFlags & VARFLAG_FRESTRICTED)) {
+				pTypeInfo->ReleaseVarDesc(pVarDesc);
+				continue;
+			}
+
+			UINT	cFetched;
+			BSTR	bstrConstantName;
+
+			if(SUCCEEDED(pTypeInfo->GetNames(pVarDesc->memid, &bstrConstantName, 1, &cFetched))) {
+				pEnum->AddProperty(bstrConstantName, pVarDesc->lpvarValue->lVal);
+				::SysFreeString(bstrConstantName);
+				bAddedOnce = true;
+			}
+			pTypeInfo->ReleaseVarDesc(pVarDesc);
+		}
+		pTypeInfo->ReleaseTypeAttr(pTypeAttr);
+
+		if(bAddedOnce) {
+			BSTR	bstrEnumName;
+
+			if(SUCCEEDED(typeLib.GetDocumentation(i, &bstrEnumName, 0, 0, 0))) {
+				AddTopLevelObject(bstrEnumName, pEnum, SCRIPTITEM_ISVISIBLE);
+				::SysFreeString(bstrEnumName);
+				bLoadedOnce = true;
+			}
+		}
+		pEnum->Release();
+	}
+	return guid == GUID_NULL || bLoadedOnce;
+}
+
 ///	@see	IActiveScriptSite::OnEnterScript
 STDMETHODIMP CAlphaScriptHost::OnEnterScript() {
 //	if(m_pDebugApplication != 0)
@@ -398,7 +512,7 @@ STDMETHODIMP CAlphaScriptHost::ProcessUrlAction(DWORD dwAction,
 		return (*pPolicy = URLPOLICY_ALLOW), S_OK;
 
 	// ȉAΏۂ Active X IuWFNĝ
-	ScriptSiteSecurityLevel	nSecurityLevel = m_nSecurityLevelForUnsafeObject;
+	ScriptSiteSecurityLevel	securityLevel = m_securityLevelForUnsafeObject;
 	CComPtr<ICatInformation>	pci;
 
 	// KpZLeBx肷̂Ɏ\ɂIuWFNgSǂ𒲂ׂB
@@ -408,16 +522,16 @@ STDMETHODIMP CAlphaScriptHost::ProcessUrlAction(DWORD dwAction,
 			0, CLSCTX_ALL, IID_ICatInformation, reinterpret_cast<void**>(&pci)))) {
 		CATID	id = CATID_SafeForScripting;
 		if(S_OK == pci->IsClassOfCategories(*reinterpret_cast<CLSID*>(pContext), 1, &id, -1, 0))
-			nSecurityLevel = m_nSecurityLevelForSafeObject;
+			securityLevel = m_securityLevelForSafeObject;
 	}
 
 	// ȉAΏۂ͈SłȂ\̂ Active X IuWFNĝ
 	memset(pPolicy, 0, cbPolicy);
 
-	if(nSecurityLevel <= SSSL_ALLOW) {
+	if(securityLevel <= SSSL_ALLOW) {
 		*pPolicy = URLPOLICY_ALLOW;
 		return S_OK;
-	} else if(nSecurityLevel == SSSL_QUERYUSER
+	} else if(securityLevel == SSSL_QUERYUSER
 			&& toBoolean(::IsWindow(m_hOwnerWindow))
 			&& !toBoolean(dwFlags & PUAF_NOUI)) {
 		// x_CAOo
@@ -480,32 +594,41 @@ STDMETHODIMP CAlphaScriptHost::QueryCustomPolicy(REFGUID guidKey,
 }
 
 ///	ŏʃIuWFNgSč폜
-void CAlphaScriptHost::_ReleaseTopLevelObjects() {
+void CAlphaScriptHost::ReleaseTopLevelObjects() {
 	for(MemberTable::iterator it = m_topLevelObjects.begin(); it != m_topLevelObjects.end(); ++it)
 		it->second->Release();
 	m_topLevelObjects.clear();
 }
 
+/// XNvgGWւ̎QƂj
+void CAlphaScriptHost::ReleaseScriptEngine() {
+	if(m_pScriptEngine != 0) {
+		m_pScriptEngine->Close();
+		m_pScriptEngine->Release();
+		m_pScriptEngine = 0;
+	}
+}
+
 /**
  *	ActiveX IuWFNg쐬ɑ΂ZLeBx̐ݒ
  *	@param bForSafeObject	Sƃ}[NĂIuWFNgɂĐݒ肷ꍇ
  *							trueB}[NĂȂIuWFNg̏ꍇ false
- *	@param nLevel			ZLeBx
+ *	@param securityLevel	ZLeBx
  */
-void CAlphaScriptHost::SetSecurityLevel(bool bForSafeObject, ScriptSiteSecurityLevel nLevel) {
+void CAlphaScriptHost::SetSecurityLevel(bool bForSafeObject, ScriptSiteSecurityLevel securityLevel) {
 	if(bForSafeObject)
-		m_nSecurityLevelForSafeObject = nLevel;
+		m_securityLevelForSafeObject = securityLevel;
 	else {
 		CComPtr<IObjectSafety>	pSafety;
 
-		m_nSecurityLevelForUnsafeObject = nLevel;
+		m_securityLevelForUnsafeObject = securityLevel;
 		if(SUCCEEDED(m_pScriptEngine->QueryInterface(IID_IObjectSafety, reinterpret_cast<void**>(&pSafety)))) {
 			DWORD	dwSupportedOpts, dwEnabledOpts;
 			if(SUCCEEDED(pSafety->GetInterfaceSafetyOptions(IID_NULL, &dwSupportedOpts, &dwEnabledOpts))
 					&& !toBoolean(dwSupportedOpts & INTERFACE_USES_SECURITY_MANAGER)
 					&& toBoolean(dwSupportedOpts & INTERFACESAFE_FOR_UNTRUSTED_CALLER))
 				pSafety->SetInterfaceSafetyOptions(IID_NULL,
-					dwSupportedOpts, (nLevel == SSSL_DISALLOW) ? INTERFACESAFE_FOR_UNTRUSTED_CALLER : 0);
+					dwSupportedOpts, (securityLevel == SSSL_DISALLOW) ? INTERFACESAFE_FOR_UNTRUSTED_CALLER : 0);
 		}
 	}
 }
@@ -528,14 +651,14 @@ void CAlphaScriptHost::Sleep(unsigned long nMilliseconds) {
  *	@param iidEvent		CxgC^[tFCX IID
  *	@param strPrefix	Cxgnh̐ړ
  */
-CAlphaScriptHost::CAdhocEventSink::CAdhocEventSink(
+CAlphaScriptHost::_CAdhocEventSink::_CAdhocEventSink(
 		IActiveScript& scriptEngine, const IID& iidEvent, const wstring& strPrefix)
 		: m_pScriptEngine(&scriptEngine), m_pConnectionPointContainer(0), m_iidEvent(iidEvent), m_strPrefix(strPrefix) {
 	m_pScriptEngine->AddRef();
 }
 
 ///	fXgN^
-CAlphaScriptHost::CAdhocEventSink::~CAdhocEventSink() {
+CAlphaScriptHost::_CAdhocEventSink::~_CAdhocEventSink() {
 	if(m_pConnectionPointContainer != 0)
 		Disconnect();
 	m_pScriptEngine->Release();
@@ -543,20 +666,18 @@ CAlphaScriptHost::CAdhocEventSink::~CAdhocEventSink() {
 
 /**
  *	CxgVNƂĐڑ
- *	@param pConnectionPoint	ڑ|Cg
+ *	@param connectionPoint	ڑ|Cg
  *	@return					IConnectionPoint::Advise Ɠ
  */
-HRESULT CAlphaScriptHost::CAdhocEventSink::Connect(IConnectionPoint* pConnectionPoint) {
-	if(pConnectionPoint == 0)
-		return E_INVALIDARG;
+HRESULT CAlphaScriptHost::_CAdhocEventSink::Connect(IConnectionPoint& connectionPoint) {
 	if(m_pConnectionPointContainer != 0)
 		return E_UNEXPECTED;
 
 	HRESULT	hr;
 
-	if(FAILED(hr = pConnectionPoint->Advise(static_cast<IUnknown*>(this), &m_dwCookie)))
+	if(FAILED(hr = connectionPoint.Advise(static_cast<IUnknown*>(this), &m_dwCookie)))
 		return hr;
-	pConnectionPoint->GetConnectionPointContainer(&m_pConnectionPointContainer);
+	connectionPoint.GetConnectionPointContainer(&m_pConnectionPointContainer);
 
 	// \bh̃G~[g
 	// (̓G[NĂ S_OK Ԃ)
@@ -602,7 +723,7 @@ HRESULT CAlphaScriptHost::CAdhocEventSink::Connect(IConnectionPoint* pConnection
  *	ڑ
  *	@return	IConnectionPoint::Unadvise Ɠ
  */
-HRESULT CAlphaScriptHost::CAdhocEventSink::Disconnect() {
+HRESULT CAlphaScriptHost::_CAdhocEventSink::Disconnect() {
 	if(m_pConnectionPointContainer == 0)
 		return E_UNEXPECTED;
 
@@ -617,7 +738,7 @@ HRESULT CAlphaScriptHost::CAdhocEventSink::Disconnect() {
 }
 
 ///	@see	IDispatch::GetIDsOfNames
-STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::GetIDsOfNames(
+STDMETHODIMP CAlphaScriptHost::_CAdhocEventSink::GetIDsOfNames(
 		REFIID riid, OLECHAR** rgszNames, unsigned int cNames, LCID lcid, DISPID* rgDispId) {
 	if(riid != IID_NULL)
 		return E_INVALIDARG;
@@ -633,21 +754,21 @@ STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::GetIDsOfNames(
 }
 
 ///	@see	IDispatch::GetTypeInfo
-STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::GetTypeInfo(UINT iTypeInfo, LCID lcid, ITypeInfo** ppTypeInfo) {
+STDMETHODIMP CAlphaScriptHost::_CAdhocEventSink::GetTypeInfo(UINT iTypeInfo, LCID lcid, ITypeInfo** ppTypeInfo) {
 	VERIFY_POINTER(ppTypeInfo);
 	*ppTypeInfo = 0;
 	return TYPE_E_ELEMENTNOTFOUND;
 }
 
 ///	@see	IDispatch::GetTypeInfoCount
-STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::GetTypeInfoCount(UINT* pcTypeInfo) {
+STDMETHODIMP CAlphaScriptHost::_CAdhocEventSink::GetTypeInfoCount(UINT* pcTypeInfo) {
 	VERIFY_POINTER(pcTypeInfo);
 	*pcTypeInfo = 0;
 	return S_OK;
 }
 
 ///	@see	IDispatch::Invoke
-STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::Invoke(DISPID dispidMember,
+STDMETHODIMP CAlphaScriptHost::_CAdhocEventSink::Invoke(DISPID dispidMember,
 		REFIID riid, LCID lcid, WORD wFlags, DISPPARAMS* pDispParams,
 		VARIANT* pVarResult, EXCEPINFO* pExcepInfo, unsigned int* puArgErr) {
 	if(riid != IID_NULL)
@@ -671,7 +792,7 @@ STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::Invoke(DISPID dispidMember,
 }
 
 ///	@see	IUnknown::QueryInterface
-STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::QueryInterface(REFIID riid, void** ppvObject) {
+STDMETHODIMP CAlphaScriptHost::_CAdhocEventSink::QueryInterface(REFIID riid, void** ppvObject) {
 	VERIFY_POINTER(ppvObject);
 
 	if(riid == m_iidEvent || riid == IID_IDispatch || riid == IID_IUnknown)
@@ -686,75 +807,65 @@ STDMETHODIMP CAlphaScriptHost::CAdhocEventSink::QueryInterface(REFIID riid, void
 // CEnumImpl class implementation
 /////////////////////////////////////////////////////////////////////////////
 
-/**
- *	RXgN^
- *	@param bIgnoreCaseOnPropertySearch	vpeBTɑ啶ʂ邩
- */
-CEnumImpl::CEnumImpl(bool bIgnoreCaseOnPropertySearch) : m_bIgnoreCase(bIgnoreCaseOnPropertySearch) {
-}
-
 /**
  *	vpeBǉ
  *	@param pwszName					vpeB
  *	@param value					l
  *	@throw std::invalid_argument	ɓ̃vpeB݂ƂX[
  */
-void CEnumImpl::AddProperty(const OLECHAR* pwszName, long value) throw(invalid_argument) {
+void CAlphaScriptHost::_CEnumImpl::AddProperty(const OLECHAR* pwszName, long value) throw(invalid_argument) {
 	assert(pwszName != 0);
 
 	static DISPID	id = 100;
-	wchar_t*		pwsz = m_bIgnoreCase ? new wchar_t[wcslen(pwszName) + 1] : const_cast<OLECHAR*>(pwszName);
+	wchar_t* const	pwsz = new wchar_t[wcslen(pwszName) + 1];
 
-	if(m_bIgnoreCase) {
-		wcscpy(pwsz, pwszName);
-		::CharLowerW(pwsz);
-	}
-	const NameToIdTable::const_iterator	it = m_mapNameTable.find(pwsz);
-	if(it != m_mapNameTable.end())
+	wcscpy(pwsz, pwszName);
+	::CharLowerW(pwsz);
+	const NameToIdTable::const_iterator	it = m_nameTable.find(pwsz);
+	if(it != m_nameTable.end())
 		throw std::invalid_argument("There is a property has same name.");
-	m_mapNameTable[pwsz] = id;
-	m_mapIdTable[id++] = value;
-	if(m_bIgnoreCase)
-		delete[] pwsz;
+	m_nameTable[pwsz] = id;
+	m_idTable[id++] = value;
+	delete[] pwsz;
 }
 
 ///	IDispatch::GetTypeInfo
-STDMETHODIMP CEnumImpl::GetTypeInfo(UINT iTypeInfo, LCID lcid, ITypeInfo** ppTypeInfo) {
+STDMETHODIMP CAlphaScriptHost::_CEnumImpl::GetTypeInfo(UINT iTypeInfo, LCID lcid, ITypeInfo** ppTypeInfo) {
 	VERIFY_POINTER(ppTypeInfo);
 	*ppTypeInfo = 0;
 	return E_NOTIMPL;
 }
 
 ///	IDispatch::GetTypeInfoCount
-STDMETHODIMP CEnumImpl::GetTypeInfoCount(UINT* pcTypeInfo) {
+STDMETHODIMP CAlphaScriptHost::_CEnumImpl::GetTypeInfoCount(UINT* pcTypeInfo) {
 	VERIFY_POINTER(pcTypeInfo);
 	*pcTypeInfo = 0;
 	return S_OK;
 }
 
 ///	IDispatch::GetIDsOfNames
-STDMETHODIMP CEnumImpl::GetIDsOfNames(REFIID riid, LPOLESTR* rgszNames, UINT cNames, LCID lcid, DISPID* rgDispId) {
+STDMETHODIMP CAlphaScriptHost::_CEnumImpl::GetIDsOfNames(
+		REFIID riid, LPOLESTR* rgszNames, UINT cNames, LCID lcid, DISPID* rgDispId) {
 	VERIFY_POINTER(rgDispId);
 	if(riid != IID_NULL || rgszNames == 0)
 		return E_INVALIDARG;
 
-	wchar_t*	pwsz = m_bIgnoreCase ? new wchar_t[wcslen(rgszNames[0]) + 1] : rgszNames[0];
+	wchar_t* const	pwsz = new wchar_t[wcslen(rgszNames[0]) + 1];
 
-	if(m_bIgnoreCase) {
-		wcscpy(pwsz, rgszNames[0]);
-		::CharLowerW(pwsz);
-	}
-	NameToIdTable::const_iterator it = m_mapNameTable.find(pwsz);
-	if(m_bIgnoreCase)
-		delete[] pwsz;
-	if(it == m_mapNameTable.end())
-		return DISP_E_UNKNOWNNAME;
-	rgDispId[0] = it->second;
-	return S_OK;
+	wcscpy(pwsz, rgszNames[0]);
+	::CharLowerW(pwsz);
+
+	NameToIdTable::const_iterator it = m_nameTable.find(pwsz);
+
+	delete[] pwsz;
+	rgDispId[0] = (it != m_nameTable.end()) ? it->second : DISPID_UNKNOWN;
+	for(UINT i = 1; i < cNames; ++i)
+		rgDispId[i] = DISPID_UNKNOWN;
+	return (rgDispId[0] != DISPID_UNKNOWN) ? S_OK : DISP_E_UNKNOWNNAME;
 }
 
 ///	IDispatch::Invoke
-STDMETHODIMP CEnumImpl::Invoke(DISPID dispidMember, REFIID riid, LCID lcid,
+STDMETHODIMP CAlphaScriptHost::_CEnumImpl::Invoke(DISPID dispidMember, REFIID riid, LCID lcid,
 		WORD wFlags, DISPPARAMS *pDispParams, VARIANT* pVarResult, EXCEPINFO* pExcepInfo, UINT* puArgErr) {
 	if(riid != IID_NULL)
 		return E_INVALIDARG;
@@ -763,8 +874,8 @@ STDMETHODIMP CEnumImpl::Invoke(DISPID dispidMember, REFIID riid, LCID lcid,
 	else if((wFlags & DISPATCH_PROPERTYGET) == 0)
 		return DISP_E_MEMBERNOTFOUND;
 
-	const IdToValueTable::const_iterator	it = m_mapIdTable.find(dispidMember);
-	if(it == m_mapIdTable.end())
+	const IdToValueTable::const_iterator	it = m_idTable.find(dispidMember);
+	if(it == m_idTable.end())
 		return DISP_E_MEMBERNOTFOUND;
 
 	pVarResult->vt = VT_I4;
