@@ -1,21 +1,23 @@
 // Unicode.cpp
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #include "StdAfx.h"
 #include "Encoder.h"
 
+using namespace Ascension;
 using namespace Ascension::Encodings;
 using namespace std;
-using namespace Manah::Text;
 
 
-DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF5, Unicode_Utf5);
-DEFINE_ENCODER_CLASS(CP_UTF7, Unicode_Utf7);
-DEFINE_ENCODER_CLASS(CP_UTF8, Unicode_Utf8);
-DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF16LE, Unicode_Utf16LE);
-DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF16BE, Unicode_Utf16BE);
-DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF32LE, Unicode_Utf32LE);
-DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF32BE, Unicode_Utf32BE);
+BEGIN_ENCODER_DEFINITION()
+	DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF5, Unicode_Utf5, 6, 1)	// max character length as in UTF-16 range
+	DEFINE_ENCODER_CLASS(CP_UTF7, Unicode_Utf7, 8, 1)
+	DEFINE_ENCODER_CLASS(CP_UTF8, Unicode_Utf8, 4, 1)			// max character length as in UTF-16 range
+	DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF16LE, Unicode_Utf16LE, 2, 1)
+	DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF16BE, Unicode_Utf16BE, 2, 1)
+	DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF32LE, Unicode_Utf32LE, 4, 1)
+	DEFINE_ENCODER_CLASS(CPEX_UNICODE_UTF32BE, Unicode_Utf32BE, 4, 1)
+END_ENCODER_DEFINITION()
 DEFINE_DETECTOR(CPEX_UNICODE_AUTODETECT, Unicode);
 
 
@@ -68,8 +70,8 @@ namespace {
 	inline size_t HasBOMOfUTF16(const uchar* pszText, size_t cch) {
 		if(cch < 2)
 			return 0;
-		if(memcmp(pszText, szBom_Utf16LE, 2) == 0)		return 1;
-		else if(memcmp(pszText, szBom_Utf16BE, 2) == 0)	return 2;
+		if(memcmp(pszText, UTF16LE_BOM, 2) == 0)		return 1;
+		else if(memcmp(pszText, UTF16BE_BOM, 2) == 0)	return 2;
 		else											return 0;
 	}
 
@@ -77,14 +79,14 @@ namespace {
 	inline size_t HasBOMOfUTF32(const uchar* pszText, size_t cch) {
 		if(cch < 4)
 			return 0;
-		if(memcmp(pszText, szBom_Utf32LE, 4) == 0)		return 1;
-		else if(memcmp(pszText, szBom_Utf32BE, 4) == 0)	return 2;
+		if(memcmp(pszText, UTF32LE_BOM, 4) == 0)		return 1;
+		else if(memcmp(pszText, UTF32BE_BOM, 4) == 0)	return 2;
 		else											return 0;
 	}
 
 	///	̐擪 UTF-8  BOM 邩ǂԂ
 	inline bool HasBOMOfUTF8(const uchar* pszText, size_t cch) {
-		return cch >= 3 && memcmp(pszText, szBom_Utf8, 3) == 0;
+		return cch >= 3 && memcmp(pszText, UTF8_BOM, 3) == 0;
 	}
 
 	///	 UTF-8 ƂĉLԂ
@@ -95,8 +97,8 @@ namespace {
 		while(true) {
 			if(i >= cch)
 				break;
-			if(pszText[i] == 0x1B)
-				break;
+//			if(pszText[i] == 0x1B)
+//				break;
 			const size_t	j = GetByteLengthAsUTF8Char(pszText + i, cch - i);
 			if(j == 0)
 				break;
@@ -105,28 +107,25 @@ namespace {
 		return i;
 	}
 
-	void DetectCodePage_Unicode(const char* psz, size_t cch, CodePage& cpResult, size_t& cchConvertable) {
+	void DetectCodePage_Unicode(const uchar* psz, size_t cch, CodePage& cpResult, size_t& cchConvertable) {
 		cpResult = 0;
 		cchConvertable = cch;
-		if(HasBOMOfUTF8(reinterpret_cast<const uchar*>(psz), cch))
+		if(HasBOMOfUTF8(psz, cch))
 			cpResult = CP_UTF8;
-		else if(size_t n = HasBOMOfUTF16(reinterpret_cast<const uchar*>(psz), cch))
+		else if(size_t n = HasBOMOfUTF16(psz, cch))
 			cpResult = (n == 1) ? CPEX_UNICODE_UTF16LE : CPEX_UNICODE_UTF16BE;
-		else if(size_t n = HasBOMOfUTF32(reinterpret_cast<const uchar*>(psz), cch))
+		else if(size_t n = HasBOMOfUTF32(psz, cch))
 			cpResult = (n == 1) ? CPEX_UNICODE_UTF32LE : CPEX_UNICODE_UTF32BE;
 		if(cpResult != 0)
 			return;
 		cpResult = CP_UTF8;
-		cchConvertable = IsUTF8String(reinterpret_cast<const uchar*>(psz), cch);
+		cchConvertable = IsUTF8String(psz, cch);
 	}
 }
 
 
 // UTF-16 little endian /////////////////////////////////////////////////////
 
-CEncoder_Unicode_Utf16LE::CEncoder_Unicode_Utf16LE() {
-}
-
 size_t CEncoder_Unicode_Utf16LE::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
@@ -145,23 +144,16 @@ size_t CEncoder_Unicode_Utf16LE::ConvertToUnicode(CTU_ARGLIST) {
 
 	size_t	iSrc = 0, iDest = 0;
 	while(iSrc + 1 < cchSrc && iDest < cchDest) {
-		pwszDest[iDest] = static_cast<uchar>(pszSrc[iSrc]) | static_cast<wchar_t>(pszSrc[iSrc + 1] << 8);
+		pwszDest[iDest] = pszSrc[iSrc] | static_cast<wchar_t>(pszSrc[iSrc + 1] << 8);
 		++iDest;
 		iSrc += 2;
 	}
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf16LE::GetMaxCharacterLength() const {
-	return 2;
-}
-
 
 // UTF-16 big endian ////////////////////////////////////////////////////////
 
-CEncoder_Unicode_Utf16BE::CEncoder_Unicode_Utf16BE() {
-}
-
 size_t CEncoder_Unicode_Utf16BE::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
@@ -180,34 +172,27 @@ size_t CEncoder_Unicode_Utf16BE::ConvertToUnicode(CTU_ARGLIST) {
 
 	size_t	iSrc = 0, iDest = 0;
 	while(iSrc + 1 < cchSrc && iDest < cchDest) {
-		pwszDest[iDest] = static_cast<wchar_t>(pszSrc[iSrc] << 8) | static_cast<uchar>(pszSrc[iSrc + 1]);
+		pwszDest[iDest] = static_cast<wchar_t>(pszSrc[iSrc] << 8) | pszSrc[iSrc + 1];
 		++iDest;
 		iSrc += 2;
 	}
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf16BE::GetMaxCharacterLength() const {
-	return 2;
-}
-
 
 // UTF-32 little endian ////////////////////////////////////////////////////////////////////
 
-CEncoder_Unicode_Utf32LE::CEncoder_Unicode_Utf32LE() {
-}
-
 size_t CEncoder_Unicode_Utf32LE::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
 	size_t	iDest = 0;
 	for(size_t iSrc = 0; iSrc < cchSrc && iDest + 3 < cchDest; ++iSrc) {
-		const CodePoint	cp = DecodeUTF16SurrogatePairToCodePoint(pwszSrc + iSrc, cchSrc - iSrc);
+		const CodePoint	cp = DecodeUtf16SurrogatesToCodePoint(pwszSrc + iSrc, cchSrc - iSrc);
 
-		pszDest[iDest + 0] = static_cast<char>((cp & 0x000000FF) >> 0);
-		pszDest[iDest + 1] = static_cast<char>((cp & 0x0000FF00) >> 8);
-		pszDest[iDest + 2] = static_cast<char>((cp & 0x00FF0000) >> 16);
-		pszDest[iDest + 3] = static_cast<char>((cp & 0xFF000000) >> 24);
+		pszDest[iDest + 0] = static_cast<uchar>((cp & 0x000000FF) >> 0);
+		pszDest[iDest + 1] = static_cast<uchar>((cp & 0x0000FF00) >> 8);
+		pszDest[iDest + 2] = static_cast<uchar>((cp & 0x00FF0000) >> 16);
+		pszDest[iDest + 3] = static_cast<uchar>((cp & 0xFF000000) >> 24);
 
 		if(cp > 0xFFFF)
 			++iSrc;
@@ -221,10 +206,8 @@ size_t CEncoder_Unicode_Utf32LE::ConvertToUnicode(CTU_ARGLIST) {
 
 	size_t	iDest = 0;
 	for(size_t iSrc = 0; iSrc + 3 < cchSrc && iDest < cchDest; iSrc += 4) {
-		const uchar*	pszSrc_ = reinterpret_cast<const uchar*>(pszSrc) + iSrc;
-		const CodePoint	cp = pszSrc_[0] + (pszSrc_[1] << 8) + (pszSrc_[2] << 16) + (pszSrc_[3] << 24);
-
-		if(EncodeCodePointToUTF16SurrogatePair(cp, pwszDest + iDest))
+		const CodePoint	cp = pszSrc[iSrc + 0] + (pszSrc[iSrc + 1] << 8) + (pszSrc[iSrc + 2] << 16) + (pszSrc[iSrc + 3] << 24);
+		if(EncodeCodePointToUtf16Surrogates(cp, pwszDest + iDest))
 			iDest += 2;
 		else
 			++iDest;
@@ -232,27 +215,20 @@ size_t CEncoder_Unicode_Utf32LE::ConvertToUnicode(CTU_ARGLIST) {
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf32LE::GetMaxCharacterLength() const {
-	return 4;
-}
-
 
 // UTF-32 big endian ////////////////////////////////////////////////////////////////////
 
-CEncoder_Unicode_Utf32BE::CEncoder_Unicode_Utf32BE() {
-}
-
 size_t CEncoder_Unicode_Utf32BE::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
 	size_t	iDest = 0;
 	for(size_t iSrc = 0; iSrc < cchSrc && iDest + 3 < cchDest; ++iSrc) {
-		const CodePoint	cp = DecodeUTF16SurrogatePairToCodePoint(pwszSrc + iSrc, cchSrc - iSrc);
+		const CodePoint	cp = DecodeUtf16SurrogatesToCodePoint(pwszSrc + iSrc, cchSrc - iSrc);
 
-		pszDest[iDest + 0] = static_cast<char>((cp & 0xFF000000) >> 24);
-		pszDest[iDest + 1] = static_cast<char>((cp & 0x00FF0000) >> 16);
-		pszDest[iDest + 2] = static_cast<char>((cp & 0x0000FF00) >> 8);
-		pszDest[iDest + 3] = static_cast<char>((cp & 0x000000FF) >> 0);
+		pszDest[iDest + 0] = static_cast<uchar>((cp & 0xFF000000) >> 24);
+		pszDest[iDest + 1] = static_cast<uchar>((cp & 0x00FF0000) >> 16);
+		pszDest[iDest + 2] = static_cast<uchar>((cp & 0x0000FF00) >> 8);
+		pszDest[iDest + 3] = static_cast<uchar>((cp & 0x000000FF) >> 0);
 
 		if(cp > 0xFFFF)
 			++iSrc;
@@ -266,10 +242,8 @@ size_t CEncoder_Unicode_Utf32BE::ConvertToUnicode(CTU_ARGLIST) {
 
 	size_t	iDest = 0;
 	for(size_t iSrc = 0; iSrc + 3 < cchSrc && iDest < cchDest; iSrc += 4) {
-		const uchar*	pszSrc_ = reinterpret_cast<const uchar*>(pszSrc) + iSrc;
-		const CodePoint	cp = pszSrc_[3] + (pszSrc_[2] << 8) + (pszSrc_[1] << 16) + (pszSrc_[0] << 24);
-
-		if(EncodeCodePointToUTF16SurrogatePair(cp, pwszDest + iDest))
+		const CodePoint	cp = pszSrc[iSrc + 3] + (pszSrc[iSrc + 2] << 8) + (pszSrc[iSrc + 1] << 16) + (pszSrc[iSrc + 0] << 24);
+		if(EncodeCodePointToUtf16Surrogates(cp, pwszDest + iDest))
 			iDest += 2;
 		else
 			++iDest;
@@ -277,10 +251,6 @@ size_t CEncoder_Unicode_Utf32BE::ConvertToUnicode(CTU_ARGLIST) {
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf32BE::GetMaxCharacterLength() const {
-	return 4;
-}
-
 
 // UTF-5 ////////////////////////////////////////////////////////////////////
 
@@ -319,83 +289,78 @@ inline size_t DecodeUTF5CharToUnicode(CodePoint* pnCodePoint, const uchar* pszSr
  *	@param cchSrc	ϊ镶̃oCg
  *	@return			ϊ̃̕oCgB0Ǝs
  */
-inline size_t EncodeUnicodeCharToUTF5(char* pszDest, const wchar_t* pwszSrc, size_t cch) {
+inline size_t EncodeUnicodeCharToUTF5(uchar* pszDest, const wchar_t* pwszSrc, size_t cch) {
 	assert(pszDest != 0 && pwszSrc != 0);
 #define D2C(n)	((n) < 0x0A) ? ((n) + '0') : ((n) - 0x0A + 'A')
 
-	const CodePoint	cp = DecodeUTF16SurrogatePairToCodePoint(pwszSrc, cch);
+	const CodePoint	cp = DecodeUtf16SurrogatesToCodePoint(pwszSrc, cch);
 
 	if(cp < 0x00000010) {
-		pszDest[0] = static_cast<char>((cp & 0x0000000F) >> 0) + 'G';
+		pszDest[0] = static_cast<uchar>((cp & 0x0000000F) >> 0) + 'G';
 		return 1;
 	} else if(cp < 0x00000100) {
-		pszDest[0] = static_cast<char>((cp & 0x000000F0) >> 4) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0x000000F0) >> 4) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 2;
 	} else if(cp < 0x00001000) {
-		pszDest[0] = static_cast<char>((cp & 0x00000F00) >> 8) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x000000F0) >> 4));
-		pszDest[2] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0x00000F00) >> 8) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x000000F0) >> 4));
+		pszDest[2] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 3;
 	} else if(cp < 0x00010000) {
-		pszDest[0] = static_cast<char>((cp & 0x0000F000) >> 12) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x00000F00) >> 8));
-		pszDest[2] = D2C(static_cast<char>((cp & 0x000000F0) >> 4));
-		pszDest[3] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0x0000F000) >> 12) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x00000F00) >> 8));
+		pszDest[2] = D2C(static_cast<uchar>((cp & 0x000000F0) >> 4));
+		pszDest[3] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 4;
 	} else if(cp < 0x00100000) {
-		pszDest[0] = static_cast<char>((cp & 0x000F0000) >> 16) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x0000F000) >> 12));
-		pszDest[2] = D2C(static_cast<char>((cp & 0x00000F00) >> 8));
-		pszDest[3] = D2C(static_cast<char>((cp & 0x000000F0) >> 4));
-		pszDest[4] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0x000F0000) >> 16) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x0000F000) >> 12));
+		pszDest[2] = D2C(static_cast<uchar>((cp & 0x00000F00) >> 8));
+		pszDest[3] = D2C(static_cast<uchar>((cp & 0x000000F0) >> 4));
+		pszDest[4] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 5;
 	} else if(cp < 0x01000000) {
-		pszDest[0] = static_cast<char>((cp & 0x00F00000) >> 20) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x000F0000) >> 16));
-		pszDest[2] = D2C(static_cast<char>((cp & 0x0000F000) >> 12));
-		pszDest[3] = D2C(static_cast<char>((cp & 0x00000F00) >> 8));
-		pszDest[4] = D2C(static_cast<char>((cp & 0x000000F0) >> 4));
-		pszDest[5] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0x00F00000) >> 20) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x000F0000) >> 16));
+		pszDest[2] = D2C(static_cast<uchar>((cp & 0x0000F000) >> 12));
+		pszDest[3] = D2C(static_cast<uchar>((cp & 0x00000F00) >> 8));
+		pszDest[4] = D2C(static_cast<uchar>((cp & 0x000000F0) >> 4));
+		pszDest[5] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 6;
 	} else if(cp < 0x10000000) {
-		pszDest[0] = static_cast<char>((cp & 0x0F000000) >> 24) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x00F00000) >> 20));
-		pszDest[2] = D2C(static_cast<char>((cp & 0x000F0000) >> 16));
-		pszDest[3] = D2C(static_cast<char>((cp & 0x0000F000) >> 12));
-		pszDest[4] = D2C(static_cast<char>((cp & 0x00000F00) >> 8));
-		pszDest[5] = D2C(static_cast<char>((cp & 0x000000F0) >> 4));
-		pszDest[6] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0x0F000000) >> 24) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x00F00000) >> 20));
+		pszDest[2] = D2C(static_cast<uchar>((cp & 0x000F0000) >> 16));
+		pszDest[3] = D2C(static_cast<uchar>((cp & 0x0000F000) >> 12));
+		pszDest[4] = D2C(static_cast<uchar>((cp & 0x00000F00) >> 8));
+		pszDest[5] = D2C(static_cast<uchar>((cp & 0x000000F0) >> 4));
+		pszDest[6] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 7;
 	} else if(cp < 0x80000000) {
-		pszDest[0] = static_cast<char>((cp & 0xF0000000) >> 28) + 'G';
-		pszDest[1] = D2C(static_cast<char>((cp & 0x0F000000) >> 24));
-		pszDest[2] = D2C(static_cast<char>((cp & 0x00F00000) >> 20));
-		pszDest[3] = D2C(static_cast<char>((cp & 0x000F0000) >> 16));
-		pszDest[4] = D2C(static_cast<char>((cp & 0x0000F000) >> 12));
-		pszDest[5] = D2C(static_cast<char>((cp & 0x00000F00) >> 8));
-		pszDest[6] = D2C(static_cast<char>((cp & 0x000000F0) >> 4));
-		pszDest[7] = D2C(static_cast<char>((cp & 0x0000000F) >> 0));
+		pszDest[0] = static_cast<uchar>((cp & 0xF0000000) >> 28) + 'G';
+		pszDest[1] = D2C(static_cast<uchar>((cp & 0x0F000000) >> 24));
+		pszDest[2] = D2C(static_cast<uchar>((cp & 0x00F00000) >> 20));
+		pszDest[3] = D2C(static_cast<uchar>((cp & 0x000F0000) >> 16));
+		pszDest[4] = D2C(static_cast<uchar>((cp & 0x0000F000) >> 12));
+		pszDest[5] = D2C(static_cast<uchar>((cp & 0x00000F00) >> 8));
+		pszDest[6] = D2C(static_cast<uchar>((cp & 0x000000F0) >> 4));
+		pszDest[7] = D2C(static_cast<uchar>((cp & 0x0000000F) >> 0));
 		return 8;
 	} else
 		return 0;
 #undef D2C
 }
 
-CEncoder_Unicode_Utf5::CEncoder_Unicode_Utf5() {
-}
-
 size_t CEncoder_Unicode_Utf5::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
-	size_t	iDest = 0;
-	size_t	cConverted = 0;
+	size_t	iDest = 0, cConverted = 0;
 	for(size_t iSrc = 0; iSrc < cchSrc && iDest < cchDest; ++iSrc) {
 		cConverted = EncodeUnicodeCharToUTF5(pszDest + iDest, pwszSrc + iSrc, cchSrc - iSrc);
-		if(cConverted == 0) {
-			pszDest[iSrc] = static_cast<const char>(pwszSrc[iSrc]);
-			++iDest;
-		} else
+		if(cConverted == 0)
+			pszDest[iDest++] = static_cast<uchar>(pwszSrc[iSrc]);
+		else
 			iDest += cConverted;
 	}
 	return iDest;
@@ -408,14 +373,13 @@ size_t CEncoder_Unicode_Utf5::ConvertToUnicode(CTU_ARGLIST) {
 	CodePoint	cp;
 
 	while(iSrc < cchSrc && iDest < cchDest) {
-		cDecoded = DecodeUTF5CharToUnicode(&cp,
-			reinterpret_cast<const uchar*>(pszSrc + iSrc), cchSrc - iSrc);
+		cDecoded = DecodeUTF5CharToUnicode(&cp, pszSrc + iSrc, cchSrc - iSrc);
 		if(cDecoded == 0) {
 			pwszDest[iDest] = pszSrc[iSrc];
 			++iDest;
 			cDecoded = 1;
 		} else {
-			EncodeCodePointToUTF16SurrogatePair(cp, pwszDest + iDest);
+			EncodeCodePointToUtf16Surrogates(cp, pwszDest + iDest);
 			iDest += (cDecoded >= 5) ? 2 : 1;
 		}
 		iSrc += cDecoded;
@@ -423,10 +387,6 @@ size_t CEncoder_Unicode_Utf5::ConvertToUnicode(CTU_ARGLIST) {
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf5::GetMaxCharacterLength() const {
-	return 6; // as UTF-16 range
-}
-
 
 // UTF-7 ////////////////////////////////////////////////////////////////////
 
@@ -445,9 +405,6 @@ inline bool IsUtf7SetD(wchar_t ch) {
 			|| ch == L'\?' || ch == L'\t' || ch == L' ' || ch == L'\r' || ch == L'\n';
 }
 
-CEncoder_Unicode_Utf7::CEncoder_Unicode_Utf7() {
-}
-
 size_t CEncoder_Unicode_Utf7::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
@@ -506,7 +463,7 @@ size_t CEncoder_Unicode_Utf7::ConvertFromUnicode(CFU_ARGLIST) {
 size_t CEncoder_Unicode_Utf7::ConvertToUnicode(CTU_ARGLIST) {
 	CTU_CHECKARGS();
 
-	static const uchar	arrBase64[] = {
+	static const uchar	base64[] = {
 		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,	//
 		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,	//
 		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,	//
@@ -549,16 +506,16 @@ size_t CEncoder_Unicode_Utf7::ConvertToUnicode(CTU_ARGLIST) {
 			// fR[h
 			while(iSrc < iBase64End) {
 				const size_t	cEncodeChars = min<size_t>(iBase64End - iSrc, 8);	// 1xɃfR[hłoCg
-											pwszDest[iDest + 0]  = arrBase64[pszSrc[iSrc + 0]] << 10;
-				if(iSrc + 1 < iBase64End)	pwszDest[iDest + 0] |= arrBase64[pszSrc[iSrc + 1]] << 4;
-				if(iSrc + 2 < iBase64End)	pwszDest[iDest + 0] |= arrBase64[pszSrc[iSrc + 2]] >> 2;
-				if(iSrc + 3 < iBase64End) {	pwszDest[iDest + 1]  = arrBase64[pszSrc[iSrc + 2]] << 14;
-											pwszDest[iDest + 1] |= arrBase64[pszSrc[iSrc + 3]] << 8;}
-				if(iSrc + 4 < iBase64End)	pwszDest[iDest + 1] |= arrBase64[pszSrc[iSrc + 4]] << 2;
-				if(iSrc + 5 < iBase64End)	pwszDest[iDest + 1] |= arrBase64[pszSrc[iSrc + 5]] >> 4;
-				if(iSrc + 6 < iBase64End) {	pwszDest[iDest + 2]  = arrBase64[pszSrc[iSrc + 5]] << 12;
-											pwszDest[iDest + 2] |= arrBase64[pszSrc[iSrc + 6]] << 6;}
-				if(iSrc + 7 < iBase64End)	pwszDest[iDest + 2] |= arrBase64[pszSrc[iSrc + 7]] << 0;
+											pwszDest[iDest + 0]  = base64[pszSrc[iSrc + 0]] << 10;
+				if(iSrc + 1 < iBase64End)	pwszDest[iDest + 0] |= base64[pszSrc[iSrc + 1]] << 4;
+				if(iSrc + 2 < iBase64End)	pwszDest[iDest + 0] |= base64[pszSrc[iSrc + 2]] >> 2;
+				if(iSrc + 3 < iBase64End) {	pwszDest[iDest + 1]  = base64[pszSrc[iSrc + 2]] << 14;
+											pwszDest[iDest + 1] |= base64[pszSrc[iSrc + 3]] << 8;}
+				if(iSrc + 4 < iBase64End)	pwszDest[iDest + 1] |= base64[pszSrc[iSrc + 4]] << 2;
+				if(iSrc + 5 < iBase64End)	pwszDest[iDest + 1] |= base64[pszSrc[iSrc + 5]] >> 4;
+				if(iSrc + 6 < iBase64End) {	pwszDest[iDest + 2]  = base64[pszSrc[iSrc + 5]] << 12;
+											pwszDest[iDest + 2] |= base64[pszSrc[iSrc + 6]] << 6;}
+				if(iSrc + 7 < iBase64End)	pwszDest[iDest + 2] |= base64[pszSrc[iSrc + 7]] << 0;
 
 				iSrc += cEncodeChars;
 				++iDest;
@@ -575,10 +532,6 @@ size_t CEncoder_Unicode_Utf7::ConvertToUnicode(CTU_ARGLIST) {
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf7::GetMaxCharacterLength() const {
-	return 8;
-}
-
 
 // UTF-8 ////////////////////////////////////////////////////////////////////
 
@@ -646,57 +599,54 @@ inline size_t DecodeUTF8CharToUnicode(CodePoint& cp, const uchar* pszSrc, size_t
  *	@param cchSrc	ϊ镶̃oCg
  *	@return			ϊ̃̕oCgB0Ǝs
  */
-inline size_t EncodeUnicodeCharToUTF8(char* pszDest, const wchar_t* pwszSrc, size_t cch) {
+inline size_t EncodeUnicodeCharToUTF8(uchar* pszDest, const wchar_t* pwszSrc, size_t cch) {
 	assert(pszDest != 0 && cch != 0);
 
-	const CodePoint	cp = DecodeUTF16SurrogatePairToCodePoint(pwszSrc, cch);
+	const CodePoint	cp = DecodeUtf16SurrogatesToCodePoint(pwszSrc, cch);
 
 	if(cp <= 0x0000007F) {	// 1oCg
 		// 0000 0000  0zzz zzzz -> 0zzz zzzz
-		pszDest[0] = static_cast<const char>(cp);
+		pszDest[0] = static_cast<uchar>(cp);
 		return 1;
 	} else if(cp <= 0x000007FF) {	// 2oCg
 		// 0000 0yyy  yyzz zzzz -> 110y yyyy  10zz zzzz
-		pszDest[0] = 0xC0 | static_cast<char>(cp >> 6);
-		pszDest[1] = 0x80 | static_cast<char>(cp & 0x003F);
+		pszDest[0] = 0xC0 | static_cast<uchar>(cp >> 6);
+		pszDest[1] = 0x80 | static_cast<uchar>(cp & 0x003F);
 		return 2;
 	} else if(cp <= 0x0000FFFF) {	// 3oCg
 		// xxxx yyyy  yyzz zzzz -> 1110 xxxx  10yy yyyy  10zz zzzz
-		pszDest[0] = 0xE0 | static_cast<char>((cp & 0xF000) >> 12);
-		pszDest[1] = 0x80 | static_cast<char>((cp & 0x0FC0) >> 6);
-		pszDest[2] = 0x80 | static_cast<char>((cp & 0x003F) >> 0);
+		pszDest[0] = 0xE0 | static_cast<uchar>((cp & 0xF000) >> 12);
+		pszDest[1] = 0x80 | static_cast<uchar>((cp & 0x0FC0) >> 6);
+		pszDest[2] = 0x80 | static_cast<uchar>((cp & 0x003F) >> 0);
 		return 3;
 	} else if(cp <= 0x0010FFFF) {	// 4oCg
 		// 0000 0000  000w wwxx  xxxx yyyy  yyzz zzzz -> 1111 0www  10xx xxxx  10yy yyyy 10zz zzzz
-		pszDest[0] = 0xF0 | static_cast<char>((cp & 0x001C0000) >> 18);
-		pszDest[1] = 0x80 | static_cast<char>((cp & 0x0003F000) >> 12);
-		pszDest[2] = 0x80 | static_cast<char>((cp & 0x00000FC0) >> 6);
-		pszDest[3] = 0x80 | static_cast<char>((cp & 0x0000003F) >> 0);
+		pszDest[0] = 0xF0 | static_cast<uchar>((cp & 0x001C0000) >> 18);
+		pszDest[1] = 0x80 | static_cast<uchar>((cp & 0x0003F000) >> 12);
+		pszDest[2] = 0x80 | static_cast<uchar>((cp & 0x00000FC0) >> 6);
+		pszDest[3] = 0x80 | static_cast<uchar>((cp & 0x0000003F) >> 0);
 		return 4;
 /*	} else if(cp <= 0x03FFFFFF) {	// 5oCg
 		// 0000 00vv  wwww wwxx  xxxx yyyy  yyzz zzzz -> 1111 10vv  10ww wwww  ...  10zz zzzz
-		pszDest[0] = 0xF8 | static_cast<char>((cp & 0x03000000) >> 24);
-		pszDest[1] = 0x80 | static_cast<char>((cp & 0x00FC0000) >> 18);
-		pszDest[2] = 0x80 | static_cast<char>((cp & 0x0003F000) >> 12);
-		pszDest[3] = 0x80 | static_cast<char>((cp & 0x00000FC0) >> 6);
-		pszDest[4] = 0x80 | static_cast<char>((cp & 0x0000003F) >> 0);
+		pszDest[0] = 0xF8 | static_cast<uchar>((cp & 0x03000000) >> 24);
+		pszDest[1] = 0x80 | static_cast<uchar>((cp & 0x00FC0000) >> 18);
+		pszDest[2] = 0x80 | static_cast<uchar>((cp & 0x0003F000) >> 12);
+		pszDest[3] = 0x80 | static_cast<uchar>((cp & 0x00000FC0) >> 6);
+		pszDest[4] = 0x80 | static_cast<uchar>((cp & 0x0000003F) >> 0);
 		return 5;
 	} else if(cp <= 0x7FFFFFFF) {	// 6oCg
 		// 0uvv vvvv  wwww wwxx  xxxx yyyy  yyzz zzzz -> 1111 110u  10vv vvvv  ...  10zz zzzz
-		pszDest[0] = 0xFC | static_cast<char>((cp & 0x40000000) >> 30);
-		pszDest[1] = 0x80 | static_cast<char>((cp & 0x3F000000) >> 24);
-		pszDest[2] = 0x80 | static_cast<char>((cp & 0x00FC0000) >> 18);
-		pszDest[3] = 0x80 | static_cast<char>((cp & 0x3F03F000) >> 12);
-		pszDest[4] = 0x80 | static_cast<char>((cp & 0x3F000FC0) >> 6);
-		pszDest[5] = 0x80 | static_cast<char>((cp & 0x3F00003F) >> 0);
+		pszDest[0] = 0xFC | static_cast<uchar>((cp & 0x40000000) >> 30);
+		pszDest[1] = 0x80 | static_cast<uchar>((cp & 0x3F000000) >> 24);
+		pszDest[2] = 0x80 | static_cast<uchar>((cp & 0x00FC0000) >> 18);
+		pszDest[3] = 0x80 | static_cast<uchar>((cp & 0x3F03F000) >> 12);
+		pszDest[4] = 0x80 | static_cast<uchar>((cp & 0x3F000FC0) >> 6);
+		pszDest[5] = 0x80 | static_cast<uchar>((cp & 0x3F00003F) >> 0);
 		return 6;
 */	} else	// s
 		return 0;
 }
 
-CEncoder_Unicode_Utf8::CEncoder_Unicode_Utf8() {
-}
-
 size_t CEncoder_Unicode_Utf8::ConvertFromUnicode(CFU_ARGLIST) {
 	CFU_CHECKARGS();
 
@@ -705,10 +655,9 @@ size_t CEncoder_Unicode_Utf8::ConvertFromUnicode(CFU_ARGLIST) {
 
 	for(size_t iSrc = 0; iSrc < cchSrc; ++iSrc) {
 		nConverted = EncodeUnicodeCharToUTF8(pszDest + iDest, pwszSrc + iSrc, cchSrc - iSrc);
-		if(nConverted == 0) {
-			pszDest[iDest] = static_cast<const char>(pwszSrc[iSrc]);
-			++iDest;
-		} else {
+		if(nConverted == 0)
+			pszDest[iDest++] = static_cast<uchar>(pwszSrc[iSrc]);
+		else {
 			if(nConverted >= 4)
 				++iSrc;
 			iDest += nConverted;
@@ -738,7 +687,7 @@ size_t CEncoder_Unicode_Utf8::ConvertToUnicode(CTU_ARGLIST) {
 			++iDest;
 			cDecoded = 1;
 		} else {
-			EncodeCodePointToUTF16SurrogatePair(cp, pwszDest + iDest);
+			EncodeCodePointToUtf16Surrogates(cp, pwszDest + iDest);
 			iDest += (cDecoded >= 4) ? 2 : 1;
 		}
 		iSrc += cDecoded;
@@ -746,8 +695,4 @@ size_t CEncoder_Unicode_Utf8::ConvertToUnicode(CTU_ARGLIST) {
 	return iDest;
 }
 
-uchar CEncoder_Unicode_Utf8::GetMaxCharacterLength() const {
-	return 4; // as UTF-16 range
-}
-
 /* [EOF] */
\ No newline at end of file
