@@ -1,27 +1,30 @@
 // BookmarkDlg.h
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _BOOKMARK_DLG_H_
 #define _BOOKMARK_DLG_H_
-#include "..\Manah\Dialog.h"
-#include "Alpha.h"
+#include "resource.h"
+#include "Ascension\AscensionCommon.h"
+#include "../Manah/Dialog.h"
 #include <map>
 
 
 namespace Alpha {
 	class CAlphaApp;
+	class CAlphaDoc;
 
 	///	[ubN}[N] _CAO
-	class CBookmarkDlg : public Manah::Windows::Controls::CDialog {
+	class CBookmarkDlg : public Manah::Windows::Controls::CLayered<
+			Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_BOOKMARKS> > {
 		// RXgN^
 	public:
-		CBookmarkDlg(const CAlphaApp& app);
+		CBookmarkDlg(CAlphaApp& app);
 
 		// \bh
 	public:
 		void	UpdateList();
 	protected:
-		void	GetItemInfo(unsigned long iItem, std::wstring& strFileName, Ascension::length_t& iLine) const;
+		void	GetItemInfo(int iItem, CAlphaDoc** ppBuffer, Ascension::length_t& iLine) const;
 		void	OnBtnDelete();
 
 		// bZ[Wnh
@@ -33,8 +36,8 @@ namespace Alpha {
 
 		// f[^o
 	private:
-		const CAlphaApp&						m_app;
-		std::map<std::wstring, unsigned int>	m_bufferIndices;	// t@C -> ^uԍ
+		CAlphaApp&							m_app;
+		std::map<CAlphaDoc*, std::size_t>	m_bufferIndices;	// obt@ -> obt@ԍ
 	};
 }
 
