@@ -1,23 +1,23 @@
 // ConfirmUnsavedDocumentDlg.h
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _CONFIRM_UNSAVED_DOCUMENT_DLG_H_
 #define _CONFIRM_UNSAVED_DOCUMENT_DLG_H_
-#include "..\Manah\Dialog.h"
-#include "..\Manah\LinkLabel.h"
+#include "../Manah/Dialog.h"
+#include "../Manah/LinkLabel.h"
 #include <vector>
 
 
 namespace Alpha {
 	///	ۑ̃t@C
 	struct TDirtyFile {
-		unsigned int	iTab;			//	^uԍ (_CAONX͎gpȂ)
-		std::wstring	strFileName;	//	t@C
-		bool			bSave;			//	ۑ邩ǂ
+		unsigned int	index;			///< ԍ (_CAONX͎gpȂ)
+		std::wstring	strFileName;	///< t@C
+		bool			bSave;			///< ۑ邩ǂ
 	};
 
 	///	[ۑĂȂhLg] _CAO
-	class CConfirmUnsavedDocumentDlg : public Manah::Windows::Controls::CDialog {
+	class CConfirmUnsavedDocumentDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_CONFIRMUNSAVEDDOCUMENTS> {
 		// bZ[Wnh
 	protected:
 		bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);
