@@ -10,9 +10,7 @@
 
 namespace Alpha {
 	///	IDebugExpressionCallBack ̕WIȎ
-	class CDebugExpressionCallBack :
-			public Armaiti::IUnknownImpl<Armaiti::MultiThreadedRefCount>,
-			public IDebugExpressionCallBack {
+	class CDebugExpressionCallBack : public IDebugExpressionCallBack {
 		// RXgN^
 	public:
 		CDebugExpressionCallBack();
@@ -21,7 +19,7 @@ namespace Alpha {
 		// \bh
 	public:
 		// IUnknown C^[tFCX
-		IMPLEMENT_UNKNOWN()
+		IMPLEMENT_UNKNOWN_MULTI_THREADED()
 		BEGIN_INTERFACE_TABLE()
 			IMPLEMENTS_LEFTMOST_INTERFACE(IDebugExpressionCallBack)
 		END_INTERFACE_TABLE()
