@@ -1,11 +1,11 @@
 // ExecuteCommandDlg.h
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _EXECUTE_COMMAND_DLG_H_
 #define _EXECUTE_COMMAND_DLG_H_
-
-#include "..\Manah\Dialog.h"
-#include "..\Manah\DosCommand.h"
+#include "resource.h"
+#include "../Manah/Dialog.h"
+#include "../Manah/DosCommand.h"
 
 
 namespace Alpha {
@@ -13,21 +13,11 @@ namespace Alpha {
 
 	///	[R}h̎s] _CAO
 	class CExecuteCommandDlg :
-			public Manah::Windows::Controls::CDialog,
+			public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_EXECUTECOMMAND>,
 			virtual public Manah::Windows::CDosCommand::ICommandEvent {
-		// f[^o
-	private:
-		CAlphaApp*					m_pApplication;
-		std::wstring				m_strCmdLine;
-		Manah::Windows::CDosCommand	m_dosCommand;
-		bool						m_bExecuting;	// R}hs
-	public:
-		bool					m_bHijackConsole;
-		bool					m_bUseUnicode;
-		
 		// RXgN^
 	public:
-		CExecuteCommandDlg(CAlphaApp* pApplication);
+		CExecuteCommandDlg(CAlphaApp& app);
 
 		// \bh
 	public:
@@ -42,6 +32,16 @@ namespace Alpha {
 		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
 		virtual void	OnCancel();												// IDCANCEL
 		virtual void	OnOK();													// IDOK
+
+		// f[^o
+	public:
+		bool	m_bHijackConsole;
+		bool	m_bUseUnicode;
+	private:
+		CAlphaApp&					m_app;
+		std::wstring				m_strCmdLine;
+		Manah::Windows::CDosCommand	m_dosCommand;
+		bool						m_bExecuting;	// R}hs
 	};
 }
 
