@@ -1,17 +1,18 @@
 // FileOperationDlg.h
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _FILE_OPERATION_DLG_H_
 #define _FILE_OPERATION_DLG_H_
-#include "..\Manah\Dialog.h"
+#include "resource.h"
+#include "../Manah/Dialog.h"
 
 
 namespace Alpha {
 	///	t@C실ʃ_CAO
-	class CFileOperationDlg : public Manah::Windows::Controls::CDialog {
+	class CFileOperationDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_FILEOPERATION> {
 		// RXgN^
 	public:
-		CFileOperationDlg(UINT nCommandID, const std::wstring& strFilePath);
+		CFileOperationDlg(UINT nCommandId, const std::wstring& strFilePath);
 
 		// bZ[Wnh
 	protected:
@@ -21,7 +22,7 @@ namespace Alpha {
 
 		// f[^o
 	private:
-		UINT			m_nCommandID;
+		const UINT		m_nCommandId;
 	public:
 		std::wstring	m_strFilePath;
 	};
