@@ -1,5 +1,5 @@
 // ScriptMacroManager.cpp
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #include "StdAfx.h"
 #include "ScriptMacroManager.h"
@@ -11,7 +11,6 @@
 //#include <winable.h>	// BlockInput
 using namespace Alpha;
 using namespace Manah;
-using namespace Manah::Text;
 using namespace Armaiti;
 using namespace Ascension::Encodings;
 using namespace std;
@@ -59,8 +58,8 @@ CScriptMacroManager::~CScriptMacroManager() {
 }
 
 /**
- *	vOCs
- *	@param i					vOC̔ԍ
+ *	}Ns
+ *	@param i					}N̔ԍ
  *	@param args					XNvgɓn
  *	@throw std::out_of_range	<var>i</var> ȂƂX[
  *	@throw EFailedToOpenScript	XNvgt@CJȂꍇX[
@@ -76,31 +75,28 @@ void CScriptMacroManager::Execute(size_t i, const vector<wstring>& args)
 	const TMacroInfo*	pInfo = m_ppMacros[i];
 	wchar_t*			pwszSource = 0;
 	wchar_t				wszFilePath[MAX_PATH];
-	CFile				scriptFile;
+	CFile<true>			scriptFile;
 	DWORD				dwFileSize;
 	wchar_t*			pwszTitle;
 	CEncoder*			pEncoder;
-	char*				pszSource;
+	uchar*				pszSource;
 
 	wcscpy(wszFilePath, m_strFilePath.c_str());
 	pwszTitle = wcsrchr(wszFilePath, L'\\');
 	wcscpy(pwszTitle + 1, pInfo->strScriptPath.c_str());
 	if(!toBoolean(::PathFileExistsW(wszFilePath)))
 		throw EFailedToOpenScript(wszFilePath);
-	try {
-		scriptFile.Open(wszFilePath, CFile::modeRead | CFile::shareDenyNone);
-	} catch(CFileException& /* e */) {
+	if(!scriptFile.Open(wszFilePath, modeRead | shareDenyNone))
 		throw EFailedToOpenScript(wszFilePath);
-	}
 	pEncoder = CEncoderFactory::GetInstance().CreateEncoder(CP_UTF8);	// XNvg UTF-8
 	dwFileSize = scriptFile.GetFileSize(0);
-	pszSource = new char[dwFileSize];
-	dwFileSize = scriptFile.Read(pszSource, dwFileSize);
+	pszSource = new uchar[dwFileSize];
+	scriptFile.Read(pszSource, dwFileSize, &dwFileSize);
 	scriptFile.Close();
 	pwszSource = new wchar_t[dwFileSize + 1];
 	dwFileSize = pEncoder->ConvertToUnicode(pwszSource, dwFileSize, pszSource, dwFileSize);
 	delete pEncoder;
-	*(pwszSource + dwFileSize) = 0;
+	pwszSource[dwFileSize] = 0;
 	delete[] pszSource;
 
 	TScriptStartupInfo*	pStartupInfo = new TScriptStartupInfo;
@@ -112,8 +108,8 @@ void CScriptMacroManager::Execute(size_t i, const vector<wstring>& args)
 	pStartupInfo->strLanguageName = pInfo->strLanguage;
 	pStartupInfo->strScriptPath = wszFilePath;
 	pStartupInfo->hInitializeEvent = ::CreateEventW(0, false, false, 0);
-	pStartupInfo->selectLanguageDialog.Create(::GetModuleHandle(0),
-		IDD_DLG_SELECTLANGUAGE, m_app.GetMainWindow()->GetSafeHwnd());
+	// _CAO̐eEBhE Alpha ɂƃfbhbNႤŎ̂悤ɂ
+	pStartupInfo->selectLanguageDialog.Create(::GetModuleHandle(0), 0);
 	m_bExecuting = true;
 	if(-1L == ::_beginthread(CScriptMacroManager::ScriptThreadProc, 0, pStartupInfo)) {
 		delete pStartupInfo;
@@ -125,14 +121,14 @@ void CScriptMacroManager::Execute(size_t i, const vector<wstring>& args)
 		throw EInvalidLanguage(pInfo->strLanguage);
 }
 
-///	vOČԂ
+///	}ŇԂ
 size_t CScriptMacroManager::GetCount() const {
 	return m_cMacros;
 }
 
 /**
- *	vOC̐Ԃ
- *	@param i			vOC̔ԍ
+ *	}N̐Ԃ
+ *	@param i			}N̔ԍ
  *	@throw out_of_range	<var>i</var> ȂƂX[
  */
 wstring CScriptMacroManager::GetDescription(size_t i) const throw(out_of_range) {
@@ -142,8 +138,8 @@ wstring CScriptMacroManager::GetDescription(size_t i) const throw(out_of_range)
 }
 
 /**
- *	vOC̖OԂ
- *	@param i			vOC̔ԍ
+ *	}N̖OԂ
+ *	@param i			}N̔ԍ
  *	@throw out_of_range	<var>i</var> ȂƂX[
  */
 wstring CScriptMacroManager::GetName(size_t i) const throw(out_of_range) {
@@ -192,14 +188,20 @@ namespace {
 //	};
 	struct _InputBlocker {
 		_InputBlocker(CAlphaApp& app) : m_app(app) {
-			CDocumentManager&	documents = m_app.GetDocumentManager();
-			for(size_t i = 0; i < documents.GetCount(); ++i)
-				::EnableWindow(documents.GetDocument(i)->GetWindow(), false);
+			const CBufferList&	buffers = m_app.GetBufferList();
+			for(size_t i = 0; i < buffers.GetCount(); ++i) {
+				const CAlphaDoc&	buffer = buffers.GetAt(i);
+				for(size_t j = 0; j < buffer.GetCount(); ++j)
+					buffer.GetView(j).EnableWindow(false);
+			}
 		}
 		~_InputBlocker() {
-			CDocumentManager&	documents = m_app.GetDocumentManager();
-			for(size_t i = 0; i < documents.GetCount(); ++i)
-				::EnableWindow(documents.GetDocument(i)->GetWindow(), true);
+			const CBufferList&	buffers = m_app.GetBufferList();
+			for(size_t i = 0; i < buffers.GetCount(); ++i) {
+				const CAlphaDoc&	buffer = buffers.GetAt(i);
+				for(size_t j = 0; j < buffer.GetCount(); ++j)
+					buffer.GetView(j).EnableWindow(true);
+			}
 		}
 		CAlphaApp&	m_app;
 	};
@@ -228,7 +230,7 @@ void __cdecl CScriptMacroManager::ScriptThreadProc(void* p) {
 		if(clsidLanguageEngine == IID_NULL)
 			CAlphaScriptHost::FindScriptEngine(pInfo->strScriptPath.c_str(), clsidLanguageEngine);
 		if(clsidLanguageEngine == IID_NULL) {
-			if(pInfo->selectLanguageDialog.DoModal() != IDOK)
+			if(IDOK != pInfo->selectLanguageDialog.DoModal())
 				goto EndThread;
 			strLanguage = pInfo->selectLanguageDialog.GetSelectedLanguage();
 			if(FAILED(::CLSIDFromProgID(strLanguage.c_str(), &clsidLanguageEngine))) {
@@ -252,7 +254,7 @@ void __cdecl CScriptMacroManager::ScriptThreadProc(void* p) {
 	inputBlocker.reset(new _InputBlocker(*pInfo->pApplication));
 
 	// XNvgs̏
-	pScriptHost = new CAlphaScriptHost(pInfo->pThis->m_app.GetMainWindow()->GetSafeHwnd(), pScriptEngine, true);
+	pScriptHost = new CAlphaScriptHost(pInfo->pThis->m_app.GetMainWindow(), pScriptEngine);
 	pAutomationScriptHost = new Ambient::CScriptHost(pScriptHost);
 	pScriptHost->SetScriptPath(pInfo->strScriptPath.c_str());
 	pScriptHost->SetSecurityLevel(true,
@@ -272,14 +274,11 @@ void __cdecl CScriptMacroManager::ScriptThreadProc(void* p) {
 	pScriptHost->AddTopLevelObject(OLESTR("WScript"), pAutomationScriptHost, dwItemTraits);
 	pScriptHost->AddTopLevelObject(OLESTR("WSH"), pAutomationScriptHost, dwItemTraits);
 
-	// ̃x瓦邽߂̃ubN
-	{
-		set<pair<wstring, CEnumImpl*> >	enums;
-		pApplication->GetEnumerations(enums);
-		for(set<pair<wstring, CEnumImpl*> >::iterator it = enums.begin(); it != enums.end(); ++it) {
-			pScriptHost->AddTopLevelObject(it->first.c_str(), it->second, dwItemTraits);
-			it->second->Release();
-		}
+	//  (萔) ̓
+	ITypeLib*	pAmbientTlb;
+	if(SUCCEEDED(::LoadTypeLib(Ambient::CAmbientTypeLibPath::GetPath(), &pAmbientTlb))) {
+		pScriptHost->LoadConstants(*pAmbientTlb);
+		pAmbientTlb->Release();	// ƍ폜
 	}
 
 	// s
@@ -329,10 +328,11 @@ EndThread:
 	if(pScriptEngine != 0) {
 		pScriptEngine->Close();
 		pScriptEngine = 0;
+		pScriptHost->ReleaseTopLevelObjects();
 	}
 
 	pInfo->pThis->m_bExecuting = false;
-	pInfo->pApplication->GetMainWindow()->SendMessage(WM_ENDSCRIPTMACRO);
+	pInfo->pApplication->GetMainWindow().SendMessage(MYWM_ENDSCRIPTMACRO);
 	delete[] pInfo->pwszSource;
 	delete pInfo;
 	::CoUninitialize();
@@ -387,7 +387,7 @@ STDMETHODIMP CScriptMacroManager::CSAXReadHandler::error(
 	pLocator->getLineNumber(&iLine);
 	pLocator->getColumnNumber(&iChar);
 	ss << L"[" << iLine << L", " << iChar << L"] " << pwchErrorMessage;
-	m_pThis->m_app.GetMainWindow()->MessageBox(L"Alpha", ss.str().c_str(), MB_ICONEXCLAMATION);
+	m_pThis->m_app.GetMainWindow().MessageBox(L"Alpha", ss.str().c_str(), MB_ICONEXCLAMATION);
 	return S_OK;
 }
 
@@ -399,7 +399,7 @@ STDMETHODIMP CScriptMacroManager::CSAXReadHandler::fatalError(
 	pLocator->getLineNumber(&iLine);
 	pLocator->getColumnNumber(&iChar);
 	ss << L"[" << iLine << L", " << iChar << L"] " << pwchErrorMessage;
-	m_pThis->m_app.GetMainWindow()->MessageBox(L"Alpha", ss.str().c_str(), MB_ICONEXCLAMATION);
+	m_pThis->m_app.GetMainWindow().MessageBox(L"Alpha", ss.str().c_str(), MB_ICONEXCLAMATION);
 	return S_OK;
 }
 
@@ -457,13 +457,11 @@ STDMETHODIMP CScriptMacroManager::CSAXReadHandler::startElement(
 			m_works.begin()->strLanguage.assign(pwszValue, cchValue);
 		if(SUCCEEDED(pAttributes->getValueFromName(WC2US(L""), 0,
 				WC2US(L"src"), 3, reinterpret_cast<unsigned short**>(&pwszValue), &cchValue))) {
-			wstring&	str = m_works.begin()->strScriptPath;
-			str.assign(pwszValue, cchValue);
-			// XbVobNXbVɕύXĂ
-			for(int i = 0; i < cchValue; ++i) {
-				if(str[i] == L'/')
-					str[i] = L'\\';
-			}
+			wchar_t*	pwszPath = new wchar_t[cchValue + 1];
+
+			replace_copy_if(pwszValue, pwszValue + cchValue, pwszPath, bind2nd(equal_to<wchar_t>(), L'/'), L'\\');
+			m_works.begin()->strScriptPath.assign(pwszValue, cchValue);
+			delete[] pwszPath;
 		}
 	} else if(wcsncmp(US2WC(pwchLocalName), L"description", cchLocalName) == 0)
 		m_nReadingPhase = 1;
