@@ -1,15 +1,15 @@
 // SelectLanguageDlg.h
-// (c) 2003-2004 exeal
+// (c) 2003-2005 exeal
 
 #ifndef _SELECT_LANGUAGE_DLG_H_
 #define _SELECT_LANGUAGE_DLG_H_
-#include "..\Manah\Dialog.h"
-#include <set>
+#include "resource.h"
+#include "../Manah/Dialog.h"
 
 
 namespace Alpha {
 	///	[GW̑I] _CAO
-	class CSelectLanguageDlg : public Manah::Windows::Controls::CDialog {
+	class CSelectLanguageDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_SELECTLANGUAGE> {
 		// \bh
 	public:
 		std::wstring	GetSelectedLanguage() const;
