@@ -3,8 +3,10 @@
 // Used by Alpha.rc
 //
 #define IDR_MENU                        101
+#define IDR_MENU_SEARCHOPTION           102
 #define IDR_ICONS                       111
 #define IDB_BMP_LOGO                    153
+#define IDR_ICON_NARROWING              154
 #define IDC_STATUSBAR                   201
 #define IDC_TOOLBAR                     202
 #define IDC_DEBUGBAR                    203
@@ -29,11 +31,9 @@
 #define IDD_DLG_SELECTLANGUAGE          522
 #define IDD_DLG_CONFIRMUNSAVEDDOCUMENTS 524
 #define IDD_DLG_FILENEWWITHFORMAT       525
-#define IDD_DLG_SEARCHOPTIONS           526
 #define IDD_DLG_ABBREVIATIONS           527
 #define IDD_DLG_NEWABBREV               528
 #define IDD_DLG_BUFFERLIST              529
-#define IDD_DLG_SELECTLANGUAGE1         530
 #define COMMAND_START                   1000
 #define CMD_FILE_NEW                    1000
 #define IDC_TAB_VIEWS                   1001
@@ -67,46 +67,64 @@
 #define IDC_COMBO_CASEFOLDING           1118
 #define IDC_COMBO_SEARCHTYPE            1119
 #define IDC_CHK_WHOLEWORD               1201
-#define IDC_CHK_AUTOCLOSE               1203
-#define IDC_CHK_AUTOSAVE                1204
-#define IDC_CHK_USEREGEXP               1218
-#define IDC_CHK_SAVESELECTION           1219
-#define IDC_CHK_GETCONSOLE              1220
-#define IDC_CHK_USEUNICODEFORINPUT      1221
-#define IDC_CHK_SHOWALLFILES            1222
-#define IDC_CHK_SHIFT                   1223
-#define IDC_CHK_EVALASSTATEMENT         1227
-#define IDC_CHK_EVALWITHNOSIDEEFFECTS   1228
-#define IDC_CHK_USEHEXADECIMAL          1230
-#define IDC_CHK_IGNORE_KANATYPE         1233
-#define IDC_CHK_SIMPLIFIEDTRADITIONAL   1234
-#define IDC_CHK_IGNORE_DIGITTYPE        1237
-#define IDC_CHK_IGNORE_WIDTH            1238
-#define IDC_CHK_IGNORE_SYMBOLS          1239
-#define IDC_CHK_IGNORE_KASHIDA          1241
-#define IDC_CHK_IGNORE_WHITESPACES      1242
-#define IDC_CHK_IGNORE_YOUONSOKUON      1243
-#define IDC_CHK_IGNORE_PRELONGEDS       1244
-#define IDC_CHK_IGNORE_REPITATIONS      1245
-#define IDC_BUTTON3                     1245
-#define IDC_CHK_IGNORE_UNSTABLEKANJIS   1246
-#define IDC_CHK_IGNORE_LEGACYKANAGLYPHS 1247
-#define IDC_CHK_IGNORE_PRELONGEDVOWELS  1248
-#define IDC_CHK_IGNORE_ZIZU             1249
-#define IDC_CHK_IGNORE_BAHA             1250
-#define IDC_CHK_IGNORE_TIDI             1251
-#define IDC_CHK_IGNORE_HYUBYU           1252
-#define IDC_CHK_IGNORE_SEZE             1253
-#define IDC_CHK_IGNORE_AYAFOLLOWINGIE   1254
-#define IDC_CHK_IGNORE_KIKUFOLLOWEDBYS  1255
-#define IDC_CHK_IGNORE_PUNCTUATIONS     1256
-#define IDC_CHK_IGNORE_DIACRITICS       1257
-#define IDC_CHK_IGNORE_VOWELS           1258
-#define IDC_CHK_IGNORE_ALEFHAMZA        1259
-#define IDC_CHK_IGNORE_CONTROLS         1260
-#define IDC_BUTTON1                     1263
-#define IDC_CHECK1                      1264
-#define IDC_COMBO1                      1265
+#define IDC_CHK_AUTOCLOSE               1202
+#define IDC_CHK_AUTOSAVE                1203
+#define IDC_CHK_USEREGEXP               1204
+#define IDC_CHK_SAVESELECTION           1205
+#define IDC_CHK_GETCONSOLE              1206
+#define IDC_CHK_USEUNICODEFORINPUT      1207
+#define IDC_CHK_SHOWALLFILES            1208
+#define IDC_CHK_SHIFT                   1209
+#define IDC_CHK_EVALASSTATEMENT         1210
+#define IDC_CHK_EVALWITHNOSIDEEFFECTS   1211
+#define IDC_CHK_USEHEXADECIMAL          1212
+#define IDC_CHK_SIMPLIFIEDTRADITIONAL   1213
+#define IDC_CHK_IGNOREPUNCTUATIONS      1214
+#define IDC_CHK_IGNORESYMBOLS           1215
+#define IDC_CHK_IGNOREWHITESPACES       1216
+#define IDC_CHK_IGNOREDIACRITICS        1217
+#define IDC_CHK_IGNOREVOWELS            1218
+#define IDC_CHK_IGNOREKASHIDA           1219
+#define IDC_CHK_IGNORECONTROLS          1220
+#define IDC_CHK_ACCENTREMOVAL           1221
+#define IDC_CHK_CANONICALDUPLICATESFOLDING 1222
+#define IDC_CHK_DASHESFOLDING           1223
+#define IDC_CHK_GREEKLETTERFORMSFOLDING 1224
+#define IDC_CHK_HEBREWALTERNATESFOLDING 1225
+#define IDC_CHK_JAMOFOLDING             1226
+#define IDC_CHK_MATHSYMBOLFOLDING       1227
+#define IDC_CHK_NATIVEDIGITFOLDING      1228
+#define IDC_CHK_NOBREAKFOLDING          1229
+#define IDC_CHK_OVERLINEFOLDING         1230
+#define IDC_CHK_POSITIONALFORMSFOLDING  1231
+#define IDC_CHK_SMALLFORMSFOLDING       1232
+#define IDC_CHK_SPACEFOLDING            1233
+#define IDC_CHK_SPACINGACCENTS          1234
+#define IDC_CHK_SUBSCRIPTFOLDING        1235
+#define IDC_CHK_SYMBOLFOLDING           1236
+#define IDC_CHK_UNDERLINEFOLDING        1237
+#define IDC_CHK_VERTICALFORMSFOLDING    1238
+#define IDC_CHK_CIRCLEDSYMBOLSEXPANSION 1239
+#define IDC_CHK_DOTTED                  1240
+#define IDC_CHK_ELLIPSISEXPANSION       1241
+#define IDC_CHK_FRACTIONEXPANSION       1242
+#define IDC_CHK_INTEGRALEXPANSION       1243
+#define IDC_CHK_LIGATUREEXPANSIONMISC   1244
+#define IDC_CHK_PARENTHESIZED           1245
+#define IDC_CHK_PRIMESEXPANSION         1246
+#define IDC_CHK_ROMANNUMERALS           1247
+#define IDC_CHK_SQUARED                 1248
+#define IDC_CHK_SQUAREDUNMARKED         1249
+#define IDC_CHK_DIGRAPHS                1250
+#define IDC_CHK_OTHERMULTIGRAPHS        1251
+#define IDC_CHK_DIACRITICREMOVAL        1252
+#define IDC_CHK_HANRADICALFOLDING       1253
+#define IDC_CHK_KANAFOLDING             1254
+#define IDC_CHK_LETTERFORMSFOLDING      1255
+#define IDC_CHK_SIMPLIFIEDHANFOLDING    1256
+#define IDC_CHK_SUPERSCRIPTFOLDING      1257
+#define IDC_CHK_SUZHOUNUMERALFOLDING    1258
+#define IDC_CHK_WIDTHFOLDING            1259
 #define IDC_RADIO_SELECTION             1301
 #define IDC_RADIO_WHOLEFILE             1302
 #define IDC_RADIO_SHARE                 1303
@@ -294,6 +312,16 @@
 #define CMD_EDIT_MAKENEXTMACRON         2087
 #define CMD_EDIT_MAKENEXTBREVE          2088
 #define CMD_EDIT_MAKENEXTCARON          2089
+#define CMD_EDIT_FIRSTCHAR              2090
+#define CMD_EDIT_LASTCHAR               2091
+#define CMD_EDIT_FIRSTCHAREXTEND        2092
+#define CMD_EDIT_LASTCHAREXTEND         2093
+#define CMD_EDIT_FIRSTCHARORLINEHOME    2094
+#define CMD_EDIT_LASTCHARORLINEEND      2095
+#define CMD_EDIT_FIRSTCHARORLINEHOMEEXTEND 2096
+#define CMD_EDIT_LASTCHARORLINEENDEXTEND 2097
+#define CMD_EDIT_NARROWTOSELECTION      2098
+#define CMD_EDIT_WIDEN                  2099
 #define CMD_EDIT_TOP                    2900
 #define CMD_EDIT_ADVANCED               2901
 #define CMD_EDIT_INSERTUNICODECTRLS     2902
@@ -326,11 +354,16 @@
 #define CMD_VIEW_WRAPBYSPECIFIEDWIDTH   4003
 #define CMD_VIEW_WRAPBYWINDOWWIDTH      4004
 #define CMD_VIEW_REFRESH                4005
-#define CMD_VIEW_SPLIT                  4006
+#define CMD_VIEW_SPLITNS                4006
 #define CMD_VIEW_NEXTBUFFER             4007
 #define CMD_VIEW_PREVBUFFER             4008
 #define CMD_VIEW_BUFFERBAR              4009
 #define CMD_VIEW_TOPMOSTALWAYS          4010
+#define CMD_VIEW_SPLITWE                4011
+#define CMD_VIEW_UNSPLITACTIVE          4012
+#define CMD_VIEW_UNSPLITOTHERS          4013
+#define CMD_VIEW_NEXTPANE               4014
+#define CMD_VIEW_PREVPANE               4015
 #define CMD_VIEW_BUFFERLIST_START       4100
 #define CMD_VIEW_BUFFERLIST_END         4800
 #define CMD_VIEW_TOP                    4900
@@ -342,7 +375,7 @@
 #define CMD_MACRO_PAUSERESTART          5004
 #define CMD_MACRO_SAVEAS                5005
 #define CMD_MACRO_LIST                  5006
-#define CMD_MACRO_INTERRUPT				5007
+#define CMD_MACRO_INTERRUPT             5007
 #define CMD_MACRO_TOP                   5900
 #define CMD_MACRO_SCRIPTS               5901
 #define CMD_TOOL_COMMONOPTION           6000
@@ -356,6 +389,7 @@
 #define CMD_HELP_TOP                    7900
 #define CMD_SPECIAL_ILLEGAL2STROKE      9000
 #define CMD_SPECIAL_WAITFOR2NDKEYS      9001
+#define CMD_SPECIAL_DISPATCHCHARINPUT   9002
 #define COMMAND_END                     10000
 #define CMD_FILE_MRULIST_START          11000
 #define CMD_FILE_MRULIST_END            11100
@@ -365,77 +399,101 @@
 #define CMD_TOOL_DOCTYPELIST_END        11300
 #define CMD_EDIT_PLUGINLIST_START       11300
 #define CMD_EDIT_PLUGINLIST_END         11500
-#define MSG_FILEISDIRTY                 20000
-#define MSG_ASKREOPEN                   20001
-#define MSG_ASKREOPENINDIRTY            20002
-#define MSG_FILEHASBEENMODIFIEDBYOTHER  20003
-#define MSG_TEXTNOTFOUND                20004
-#define MSG_REPLACESUCCEEDED            20005
-#define MSG_FAILEDTOLOADREGEXPENGINE    20006
-#define MSG_REGEXPPATTERNSYNTAXERROR    20007
-#define MSG_EXENOTREGISTERED            20008
-#define MSG_FAILEDTORUNEXE              20009
-#define MSG_FAILEDTOLOAD                20010
-#define MSG_MACRORECORDING              20011
+#define MSG_FILE_IS_DIRTY               20000
+#define MSG_ASK_REOPEN                  20001
+#define MSG_ASK_REOPEN_IN_DIRTY         20002
+#define MSG_FILE_HAS_BEEN_MODIFIED_BY_OTHER 20003
+#define MSG_TEXT_NOT_FOUND              20004
+#define MSG_REPLACE_SUCCEEDED           20005
+#define MSG_FAILED_TO_LOAD_REGEXP_ENGINE 20006
+#define MSG_REGEXP_PATTERN_SYNTAX_ERROR 20007
+#define MSG_EXE_NOT_REGISTERED          20008
+#define MSG_FAILED_TO_RUN_EXE           20009
+#define MSG_FAILED_TO_LOAD              20010
+#define MSG_MACRO_RECORDING             20011
 #define MSG_DEBUGGING                   20012
-#define MSG_INSERTMODE                  20013
-#define MSG_OVERTYPEMODE                20014
-#define MSG_DEFAULTFILEFILTER           20015
-#define MSG_READONLYTITLE               20016
-#define MSG_CARETPOSITION               20017
-#define MSG_ISEARCHPROMPT               20018
-#define MSG_ISEARCHNOTFOUNDPROMPT       20019
-#define MSG_FAILEDTOOPERATEFILE         20020
-#define MSG_REOPENEDASREADONLY          20021
-#define MSG_FAILEDTOREOPEN              20022
-#define MSG_FILEACCESSDENIED            20023
-#define MSG_CODEPAGEISNOTINSTALLED      20024
-#define MSG_UNKNOWNERROR                20025
-#define MSG_OPENEDASREADONLY            20026
-#define MSG_FAILEDTODETECTCODEPAGE      20027
-#define MSG_FOUNDILLEGALCHARACTER       20028
-#define MSG_TOOLARGEFILE                20029
-#define MSG_FILENOTFOUND                20030
-#define MSG_FAILEDTOSENDTOMAILER        20031
-#define MSG_FAILEDTOPARSEXML            20032
-#define MSG_CANNOTSTARTOUTLINEPARSE     20033
-#define MSG_FAILEDTOLOADPLUGIN          20034
-#define MSG_ILLEGALCODEPAGE             20035
-#define MSG_FAILEDTORESOLVESHORTCUT     20036
-#define MSG_ILLEGALSCRIPTLANGUAGENAME   20037
-#define MSG_FAILEDTOLOADSAXPARSER       20038
-#define MSG_FAILEDTOOPENMACROSCRIPT     20039
-#define MSG_FILECONTAINSILLEGALCHARS    20040
-#define MSG_INDICATECANEXPANDABBREV     20041
-#define MSG_ISEARCHTEXTISEMPTY          20042
-#define MSG_MATCHCASE                   20043
-#define MSG_IGNOREASCIICASE             20044
-#define MSG_CASEFOLDINGSIMPLE           20045
-#define MSG_CASEFOLDINGFULL             20046
-#define MSG_RISEARCHPROMPT              20047
-#define MSG_RISEARCHNOTFOUNDPROMPT      20048
-#define MSG_RISEARCHTEXTISEMPTY         20049
-#define MSG_LINENUMBERRANGE             20050
-#define MSG_CONFLICTEDABBREVIATION      20051
-#define MSG_MATCHBRACKETOUTOFVIEW       20052
-#define MSG_REGEXPRUNTIMEERROR          20053
-#define MSG_LOADINGFILE                 20054
-#define MSG_WAITINGFOR2NDKEYS           20055
-#define MSG_ILLEGAL2STROKECOMBINATION   20056
-#define MSG_ISEARCHBADREGEXP            20057
-#define MSG_RISEARCHBADREGEXP           20058
-#define MSG_LITERALSEARCH				20059
-#define MSG_REGEXPSEARCH				20060
-#define MSG_MIGEMOSEARCH				20061
+#define MSG_INSERT_MODE                 20013
+#define MSG_OVERTYPE_MODE               20014
+#define MSG_DEFAULT_OPEN_FILE_FILTER    20015
+#define MSG_READONLY_TITLE              20016
+#define MSG_CARET_POSITION              20017
+#define MSG_ISEARCH_PROMPT              20018
+#define MSG_ISEARCH_NOT_FOUND_PROMPT    20019
+#define MSG_FAILED_TO_OPERATE_FILE      20020
+#define MSG_REOPENED_AS_READONLY        20021
+#define MSG_FAILED_TO_REOPEN            20022
+#define MSG_FILE_ACCESS_DENIED          20023
+#define MSG_CODEPAGE_IS_NOT_INSTALLED   20024
+#define MSG_UNKNOWN_ERROR               20025
+#define MSG_OPENED_AS_READONLY          20026
+#define MSG_FAILED_TO_DETECT_CODEPAGE   20027
+#define MSG_FOUND_ILLEGAL_CHARACTER     20028
+#define MSG_TOO_LARGE_FILE              20029
+#define MSG_FILE_NOT_FOUND              20030
+#define MSG_FAILED_TO_SEND_TO_MAILER    20031
+#define MSG_FAILED_TO_PARSE_XML         20032
+#define MSG_CANNOT_START_OUTLINE_PARSE  20033
+#define MSG_FAILED_TO_LOAD_PLUGIN       20034
+#define MSG_ILLEGAL_CODEPAGE            20035
+#define MSG_FAILED_TO_RESOLVE_SHORTCUT  20036
+#define MSG_ILLEGAL_SCRIPT_LANGUAGE_NAME 20037
+#define MSG_FAILED_TO_LOAD_SAX_PARSER   20038
+#define MSG_FAILED_TO_OPEN_MACRO_SCRIPT 20039
+#define MSG_UNCONVERTABLE_UCS_CHAR      20040
+#define MSG_INDICATE_CAN_EXPAND_ABBREV  20041
+#define MSG_ISEARCH_TEXT_IS_EMPTY       20042
+#define MSG_MATCH_CASE                  20043
+#define MSG_IGNORE_ASCII_CASE           20044
+#define MSG_CASEFOLDING_SIMPLE          20045
+#define MSG_CASEFOLDING_FULL            20046
+#define MSG_RISEARCH_PROMPT             20047
+#define MSG_RISEARCH_NOT_FOUND_PROMPT   20048
+#define MSG_RISEARCH_TEXT_IS_EMPTY      20049
+#define MSG_LINE_NUMBER_RANGE           20050
+#define MSG_CONFLICTED_ABBREVIATION     20051
+#define MSG_MATCH_BRACKET_OUT_OF_VIEW   20052
+#define MSG_REGEXP_RUNTIME_ERROR        20053
+#define MSG_LOADING_FILE                20054
+#define MSG_WAITING_FOR_2ND_KEYS        20055
+#define MSG_ILLEGAL_2STROKE_COMBINATION 20056
+#define MSG_ISEARCH_BAD_REGEXP          20057
+#define MSG_RISEARCH_BAD_REGEXP         20058
+#define MSG_LITERAL_SEARCH              20059
+#define MSG_REGEXP_SEARCH               20060
+#define MSG_MIGEMO_SEARCH               20061
+#define MSG_UNCONVERTABLE_NATIVE_CHAR   20062
+#define MSG_FAILED_TO_LOCK_FILE         20063
+#define MSG_FAILED_TO_WRITE_FOR_FULLDISK 20064
+#define MSG_FAILED_TO_WRITE_FOR_READONLY 20065
+#define MSG_UNSUPPORTED_OS_VERSION      20066
+#define MSG_UNCHANGE_BREAK_TYPE         20067
+#define MSG_BUFFERBAR_CAPTION           20068
+#define MSG_ABBREVIATION                20069
+#define MSG_EXPANDED_ABBREVIATION       20070
+#define MSG_LINE                        20071
+#define MSG_POSITION                    20072
+#define MSG_SELECTALL                   20073
+#define MSG_UNSELECT_ALL                20074
+#define MSG_SELECT_DIRECTORY            20075
+#define MSG_FILE_OPERATION              20076
+#define MSG_RENAME_FILE                 20077
+#define MSG_COPY_FILE                   20078
+#define MSG_MOVE_FILE                   20079
+#define MSG_INVOKABLE_LINK_POPUP        20080
+#define MSG_NARROWING                   20081
+#define MSG_DEFAULT_UNTITLED_BUFFER     20082
+#define MSG_SAVE_FILE_FILTER            20083
+#define MSG_FILE_IS_USED_BY_OTHER_PROCESS	20084
+#define MSG_BAD_REGEX_PATTERN_START		20085
 
 // Next default values for new objects
 // 
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_NO_MFC                     1
-#define _APS_NEXT_RESOURCE_VALUE        149
-#define _APS_NEXT_COMMAND_VALUE         40002
-#define _APS_NEXT_CONTROL_VALUE         1266
-#define _APS_NEXT_SYMED_VALUE           101
+#define _APS_NEXT_RESOURCE_VALUE        159
+#define _APS_NEXT_COMMAND_VALUE         40048
+#define _APS_NEXT_CONTROL_VALUE         1308
+#define _APS_NEXT_SYMED_VALUE           104
 #endif
 #endif
