@@ -14,7 +14,7 @@ namespace GDI {
 // CGdiObject class definition
 /////////////////////////////////////////////////////////////////////////////
 
-class CGdiObject : public CObject {
+class CGdiObject : public CSelfAssertable {
 	// constructors
 public:
 	CGdiObject();
@@ -64,10 +64,8 @@ public:
 	bool	LoadMappedBitmap(uint nBitmapId, uint nFlags = 0, LPCOLORMAP lpColorMap = 0, int nMapSize = 0);
 	bool	CreateBitmap(int nWidth, int nHeight, uint nPlanes, uint nBitCount, const void* lpBits);
 	bool	CreateBitmapIndirect(const BITMAP& bitmap);
-	template<bool bDCIsDisposable>
-	bool	CreateCompatibleBitmap(const CDC<bDCIsDisposable>& dc, int nWidth, int nHeight);
-	template<bool bDCIsDisposable>
-	bool	CreateDiscardableBitmap(const CDC<bDCIsDisposable>& dc, int nWidth, int nHeight);
+	bool	CreateCompatibleBitmap(const CDC& dc, int nWidth, int nHeight);
+	bool	CreateDiscardableBitmap(const CDC& dc, int nWidth, int nHeight);
 	bool	GetBitmap(BITMAP& bitmap) const;
 	DWORD	SetBitmapBits(DWORD dwCount, const void* lpBits);
 	DWORD	GetBitmapBits(DWORD dwCount, void* lpBits) const;
@@ -150,8 +148,7 @@ public:
 
 	HPALETTE	GetSafeHandle() const;
 	bool		CreatePalette(const LOGPALETTE& logpalette);
-	template<bool bDCIsDisposable>
-	bool		CreateHalftonePalette(CDC<bDCIsDisposable>& dc);
+	bool		CreateHalftonePalette(CDC& dc);
 	void		AnimatePalette(uint iStart, uint cEntries, const PALETTEENTRY& palettecolors);
 	uint		GetNearestPaletteIndex(COLORREF clr) const;
 	bool		ResizePalette(uint cEntries);
@@ -215,8 +212,7 @@ public:
 	bool	CreateRoundRectRgn(int x1, int y1, int x2, int y2, int x3, int y3);
 	int		CombineRgn(const CRgn& oRgn1, const CRgn& oRgn2, int nCombineMode);
 	int		CopyRgn(const CRgn& oRgn);
-	template<bool bDCIsDisposable>
-	bool	CreateFromPath(const CDC<bDCIsDisposable>& dc);
+	bool	CreateFromPath(const CDC& dc);
 	bool	CreateFromData(const XFORM* lpXForm, int cDatas, const RGNDATA* pRgnData);
 	bool	EqualRgn(const CRgn& oRgn) const;
 	int		GetRegionData(LPRGNDATA lpRgnData, int cDatas) const;
@@ -297,16 +293,14 @@ inline bool CBitmap::CreateBitmapIndirect(const BITMAP& bitmap) {
 	return m_hGdiObject != 0;
 }
 
-template<bool bDCIsDisposable>
-inline bool CBitmap::CreateCompatibleBitmap(const CDC<bDCIsDisposable>& dc, int nWidth, int nHeight) {
+inline bool CBitmap::CreateCompatibleBitmap(const CDC& dc, int nWidth, int nHeight) {
 	if(m_hGdiObject != 0)
 		return false;
 	m_hGdiObject = ::CreateCompatibleBitmap(dc, nWidth, nHeight);
 	return m_hGdiObject != 0;
 }
 
-template<bool bDCIsDisposable>
-inline bool CBitmap::CreateDiscardableBitmap(const CDC<bDCIsDisposable>& dc, int nWidth, int nHeight) {
+inline bool CBitmap::CreateDiscardableBitmap(const CDC& dc, int nWidth, int nHeight) {
 	if(m_hGdiObject != 0)
 		return false;
 	m_hGdiObject = ::CreateDiscardableBitmap(dc, nWidth, nHeight);
@@ -542,7 +536,7 @@ inline bool CPalette::Attach(HPALETTE hPalette) {
 	return CGdiObject::_Attach(hPalette);
 }
 
-template<bool bDCIsDisposable> inline bool CPalette::CreateHalftonePalette(CDC<bDCIsDisposable>& dc) {
+inline bool CPalette::CreateHalftonePalette(CDC& dc) {
 	if(m_hGdiObject != 0)
 		return false;
 	m_hGdiObject = ::CreateHalftonePalette(dc);
@@ -699,7 +693,7 @@ inline bool CRgn::CreateFromData(const XFORM* lpXForm, int cDatas, const RGNDATA
 	return (m_hGdiObject != 0);
 }
 
-template<bool bDCIsDisposable> inline bool CRgn::CreateFromPath(const CDC<bDCIsDisposable>& dc) {
+inline bool CRgn::CreateFromPath(const CDC& dc) {
 	if(m_hGdiObject != 0)
 		return false;
 	m_hGdiObject = ::PathToRegion(dc);
