@@ -16,15 +16,11 @@ namespace Manah {
 namespace Windows {
 namespace Controls {
 
-class CListCtrl : public CWindow {
+class CListCtrl : public CCommonControl<CListCtrl> {
+	DEFINE_CLASS_NAME(WC_LISTVIEW)
+
 	// \bh
 public:
-	/* 쐬 */
-	bool	Attach(HWND hWnd, bool bSubClass = false);
-	bool	Create(bool bSubClass, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id);
-	bool	CreateEx(bool bSubClass, DWORD dwExStyle,
-				DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id);
-
 	/*  */
 	SIZE		ApproximateViewRect(const SIZE& size, int iCount = -1) const;
 	COLORREF	GetBkColor() const;
@@ -100,7 +96,7 @@ public:
 	bool		DeleteAllItems();
 	bool		DeleteColumn(int iCol);
 	bool		DeleteItem(int iItem);
-	CEdit*		EditLabel(int iItem);
+	CEdit&		EditLabel(int iItem);
 	bool		EnsureVisible(int iItem, bool bPartialOK);
 	int			FindItem(LVFINDINFO* pFindInfo, int iStart = -1) const;
 	int			HitTest(LVHITTESTINFO& hitTestInfo) const;
@@ -117,8 +113,6 @@ public:
 	bool		Scroll(const SIZE& size);
 	bool		SortItems(PFNLVCOMPARE pfnCompare, DWORD dwData);
 	bool		Update(int iItem);
-protected:
-	OVERRIDE_STANDARD_DISPATCH_EVENT(CListCtrl);
 };
 
 
@@ -143,64 +137,11 @@ inline bool CListCtrl::Arrange(UINT nCode) {
 	return toBoolean(SendMessage(LVM_ARRANGE, nCode));
 }
 
-inline bool CListCtrl::Attach(HWND hWnd, bool bSubClass /* = false */) {
-	AssertValid();
-
-	if(IsWindow() || !::IsWindow(hWnd) || m_OldProc != 0)
-		return false;
-	m_hWnd = hWnd;
-
-	if(bSubClass) {
-		m_OldProc = reinterpret_cast<WNDPROC>(SetWindowLong(
-			GWL_WNDPROC, reinterpret_cast<LPARAM>(STANDARD_WINDOW_CLASS_WNDPROC(CListCtrl))));
-		assert(m_OldProc != STANDARD_WINDOW_CLASS_WNDPROC(CListCtrl));
-		m_lOldUserData = GetWindowLong(GWL_USERDATA);
-		SendMessage(WM_MATTACH, 0, reinterpret_cast<LPARAM>(this));
-	}
-
-	return true;
-}
-
-inline bool CListCtrl::Create(bool bSubClass, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id) {
-	AssertValid();
-
-	m_hWnd = ::CreateWindow(WC_LISTVIEW, _T(""),
-		dwStyle, rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-		hwndParent, reinterpret_cast<HMENU>(id), reinterpret_cast<HINSTANCE>(::GetModuleHandle(0)), 0L);
-	if(m_hWnd == 0)
-		return false;
-	if(bSubClass){
-		m_OldProc = reinterpret_cast<WNDPROC>(SetWindowLong(
-			GWL_WNDPROC, reinterpret_cast<LPARAM>(STANDARD_WINDOW_CLASS_WNDPROC(CListCtrl))));
-		SendMessage(WM_MATTACH, 0, reinterpret_cast<LPARAM>(this));
-	}
-
-	return true;
-}
-
 inline Manah::Windows::CImageList* CListCtrl::CreateDragImage(int iItem, LPPOINT lpPoint) {
 	return CImageList::FromHandlePermanent(reinterpret_cast<HIMAGELIST>(
 		SendMessage(LVM_CREATEDRAGIMAGE, iItem, reinterpret_cast<LPARAM>(lpPoint))));
 }
 
-inline bool CListCtrl::CreateEx(bool bSubClass, DWORD dwExStyle,
-		DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id) {
-	AssertValid();
-
-	m_hWnd = ::CreateWindowEx(dwExStyle, WC_LISTVIEW, _T(""),
-		dwStyle, rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-		hwndParent, reinterpret_cast<HMENU>(id), reinterpret_cast<HINSTANCE>(::GetModuleHandle(0)), 0L);
-	if(m_hWnd == 0)
-		return false;
-	if(bSubClass) {
-		m_OldProc = reinterpret_cast<WNDPROC>(SetWindowLong(
-			GWL_WNDPROC, reinterpret_cast<LPARAM>(STANDARD_WINDOW_CLASS_WNDPROC(CListCtrl))));
-		SendMessage(WM_MATTACH, 0, reinterpret_cast<LPARAM>(this));
-	}
-
-	return true;
-}
-
 inline bool CListCtrl::DeleteAllItems() {
 	return toBoolean(SendMessage(LVM_DELETEALLITEMS));
 }
@@ -213,16 +154,10 @@ inline bool CListCtrl::DeleteItem(int iItem) {
 	return toBoolean(SendMessage(LVM_DELETEITEM, iItem));
 }
 
-inline LRESULT CListCtrl::DispatchEvent(UINT message, WPARAM wParam, LPARAM lParam) {
-	if(PreTranslateMessage(message, wParam, lParam))
-		return false;
-	return CWindow::DispatchEvent(message, wParam, lParam);
-}
-
-inline CEdit* CListCtrl::EditLabel(int iItem) {
-	static CEdit	oEdit;
-	oEdit.Attach(reinterpret_cast<HWND>(SendMessage(LVM_EDITLABEL, iItem)));
-	return &oEdit;
+inline CEdit& CListCtrl::EditLabel(int iItem) {
+	static CEdit	editControl;
+	editControl.Attach(reinterpret_cast<HWND>(SendMessage(LVM_EDITLABEL, iItem)));
+	return editControl;
 }
 
 inline bool CListCtrl::EnsureVisible(int iItem, bool bPartialOK) {
@@ -274,14 +209,14 @@ inline int CListCtrl::GetCountPerPage() const {
 
 inline CEdit* CListCtrl::GetEditControl() const {
 	AssertValidAsWindow();
-	static CEdit	oEdit;
+	static CEdit	editControl;
 	HWND			hEdit;
 	
 	hEdit = reinterpret_cast<HWND>(::SendMessage(m_hWnd, LVM_GETEDITCONTROL, 0, 0L));
 	if(hEdit == 0)
 		return 0;
-	oEdit.Attach(hEdit);
-	return &oEdit;
+	editControl.Attach(hEdit);
+	return &editControl;
 }
 
 inline DWORD CListCtrl::GetExtendedStyle() const {
@@ -449,7 +384,7 @@ inline int CListCtrl::InsertItem(int iItem, const TCHAR* lpszText) {
 	item.mask = LVIF_TEXT;
 	item.iItem = iItem;
 	item.pszText = const_cast<TCHAR*>(lpszText);
-	item.cchTextMax = _tcslen(lpszText);
+	item.cchTextMax = std::_tcslen(lpszText);
 
 	return InsertItem(item);
 }
@@ -461,7 +396,7 @@ inline int CListCtrl::InsertItem(int iItem, const TCHAR* lpszText, int iImage) {
 	item.mask = LVIF_TEXT | LVIF_IMAGE;
 	item.iItem = iItem;
 	item.pszText = const_cast<TCHAR*>(lpszText);
-	item.cchTextMax = _tcslen(lpszText);
+	item.cchTextMax = std::_tcslen(lpszText);
 	item.iImage = iImage;
 
 	return InsertItem(item);
@@ -469,7 +404,7 @@ inline int CListCtrl::InsertItem(int iItem, const TCHAR* lpszText, int iImage) {
 
 inline int CListCtrl::InsertItem(UINT nMask, int iItem, const TCHAR* lpszText, UINT nState, UINT nStateMask, int iImage, LPARAM lParam) {
 	LVITEM	item = {
-		nMask, iItem, 0, nState, nStateMask, const_cast<TCHAR*>(lpszText), _tcslen(lpszText), iImage, lParam
+		nMask, iItem, 0, nState, nStateMask, const_cast<TCHAR*>(lpszText), std::_tcslen(lpszText), iImage, lParam
 	};
 
 	return InsertItem(item);
@@ -596,7 +531,7 @@ inline bool CListCtrl::SetItemData(int iItem, DWORD dwData) {
 }
 
 inline bool CListCtrl::SetItem(int iItem, int iSubItem, UINT nMask, const TCHAR* lpszItem, int iImage, UINT nState, UINT nStateMask, LPARAM lParam) {
-	LVITEM	item = {nMask, iItem, iSubItem, nState, nStateMask, const_cast<TCHAR*>(lpszItem), _tcslen(lpszItem), iImage};
+	LVITEM	item = {nMask, iItem, iSubItem, nState, nStateMask, const_cast<TCHAR*>(lpszItem), std::_tcslen(lpszItem), iImage};
 	return toBoolean(SendMessage(LVM_SETITEM, 0, reinterpret_cast<LPARAM>(&item)));
 }
 
