@@ -11,12 +11,11 @@ namespace Manah {
 namespace Windows {
 namespace Controls {
 
-class CToolbar : public CWindow {
+class CToolbar : public CCommonControl<CToolbar> {
 	// \bh
 public:
 	/* 쐬 */
-	bool	Create(DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id);
-	bool	CreateEx(DWORD dwExStyle, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id);
+	DEFINE_CLASS_NAME(TOOLBARCLASSNAME)
 
 	/*  */
 	bool		GetAnchorHighlight() const;
@@ -62,6 +61,7 @@ public:
 	bool		SetButtonSize(const SIZE& size);
 	bool		SetButtonSize(int cx, int cy);
 	void		SetButtonStructSize(std::size_t nSize = sizeof(TBBUTTON));
+	void		SetButtonText(int id, const TCHAR* lpszText);
 	void		SetColorScheme(const COLORSCHEME& scheme);
 	bool		SetButtonWidth(int cxMin, int cxMax);
 	bool		SetCommandId(int index, UINT id);
@@ -163,18 +163,6 @@ inline UINT CToolbar::CommandToIndex(int id) const {
 	return static_cast<UINT>(UNCONST_THIS->SendMessage(TB_COMMANDTOINDEX, id));
 }
 
-inline bool CToolbar::Create(DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id) {
-	return CWindow::Create(false, TOOLBARCLASSNAME, _T(""), dwStyle,
-		rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-		hwndParent, reinterpret_cast<HMENU>(id));
-}
-
-inline bool CToolbar::CreateEx(DWORD dwExStyle, DWORD dwStyle, const RECT& rect, HWND hwndParent, UINT id) {
-	return CWindow::CreateEx(false, dwExStyle, TOOLBARCLASSNAME, _T(""), dwStyle,
-		rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-		hwndParent, reinterpret_cast<HMENU>(id));
-}
-
 inline void CToolbar::Customize() {
 	SendMessage(TB_CUSTOMIZE);
 }
@@ -422,6 +410,15 @@ inline void CToolbar::SetButtonStructSize(std::size_t nSize /* = sizeof(TBBUTTON
 	SendMessage(TB_BUTTONSTRUCTSIZE, nSize);
 }
 
+inline void CToolbar::SetButtonText(int id, const TCHAR* lpszText) {
+	TBBUTTONINFO	tbi;
+	std::memset(&tbi, 0, sizeof(TBBUTTONINFO));
+	tbi.cbSize = sizeof(TBBUTTONINFO);
+	tbi.dwMask = TBIF_TEXT;
+	tbi.pszText = const_cast<TCHAR*>(lpszText);
+	SendMessage(TB_SETBUTTONINFO, id, reinterpret_cast<LPARAM>(&tbi));
+}
+
 inline bool CToolbar::SetButtonWidth(int cxMin, int cxMax) {
 	return toBoolean(SendMessage(TB_SETBUTTONWIDTH, 0, MAKELPARAM(cxMin, cxMax)));
 }
