@@ -277,7 +277,7 @@ inline bool CTreeCtrl::GetItemText(HTREEITEM hItem, TCHAR* lpszText) const {
 	item.hItem = hItem;
 	item.mask = TVIF_TEXT;
 	item.pszText = lpszText;
-	item.cchTextMax = _tcslen(lpszText) + 1;
+	item.cchTextMax = std::_tcslen(lpszText) + 1;
 	if(UNCONST_THIS->SendMessage(TVM_GETITEM, 0, reinterpret_cast<LPARAM>(&item))) {
 		lpszText = item.pszText;
 		return true;
