@@ -165,25 +165,25 @@ public:
 	// methods
 public:
 	/* attributes */
-	void		GetCreationTime(FILETIME& timeStamp) const;
-	tstring		GetFileName() const;
-	tstring		GetFilePath() const;
-	ULONGLONG	GetFileSize() const;
-	tstring		GetFileTitle() const;
-	tstring		GetFileUrl() const;
-	void		GetLastAccessTime(FILETIME& timeStamp) const;
-	void		GetLastWriteTime(FILETIME& timeStamp) const;
-	tstring		GetRoot() const;
-	bool		IsArchived() const;
-	bool		IsCompressed() const;
-	bool		IsDirectory() const;
-	bool		IsDots() const;
-	bool		IsHidden() const;
-	bool		IsNormal() const;
-	bool		IsReadOnly() const;
-	bool		IsSystem() const;
-	bool		IsTemporary() const;
-	bool		MatchesMask(DWORD dwMask) const;
+	void			GetCreationTime(FILETIME& timeStamp) const;
+	std::tstring	GetFileName() const;
+	std::tstring	GetFilePath() const;
+	ULONGLONG		GetFileSize() const;
+	std::tstring	GetFileTitle() const;
+	std::tstring	GetFileUrl() const;
+	void			GetLastAccessTime(FILETIME& timeStamp) const;
+	void			GetLastWriteTime(FILETIME& timeStamp) const;
+	std::tstring	GetRoot() const;
+	bool			IsArchived() const;
+	bool			IsCompressed() const;
+	bool			IsDirectory() const;
+	bool			IsDots() const;
+	bool			IsHidden() const;
+	bool			IsNormal() const;
+	bool			IsReadOnly() const;
+	bool			IsSystem() const;
+	bool			IsTemporary() const;
+	bool			MatchesMask(DWORD dwMask) const;
 
 	/* operations */
 	void	Close();
@@ -207,15 +207,15 @@ public:
 	/* open and read the clipboard text */
 	static DWORD	GetClipboardTextSize(HWND hWnd);	// return SIZE (byte length) of clipboard text
 	static bool		ReadClipboardText(					// read multi-bytes text from the clipboard
-		HWND hWnd, char* pszText, size_t cch);			//  as format CF_TEXT
+		HWND hWnd, char* pszText, std::size_t cch);		//  as format CF_TEXT
 	static bool		ReadClipboardText(					// read wide-characters from the clipboard
-		HWND hWnd, wchar_t* pszText, size_t cch);		//  as format CF_UNICODETEXT
+		HWND hWnd, wchar_t* pszText, std::size_t cch);	//  as format CF_UNICODETEXT
 
 	/* open and set the clipboard with CF_TEXT format text */
 	static bool	SetClipboardText(		// set multi-bytes text to the clipboard
-		HWND hWnd, const char* pszText, size_t cch = -1);
+		HWND hWnd, const char* pszText, std::size_t cch = -1);
 	static bool	SetClipboardText(		// set wide-characters to the clipboard
-		HWND hWnd, const wchar_t* pszText, size_t cch = -1);
+		HWND hWnd, const wchar_t* pszText, std::size_t cch = -1);
 
 	/* basic clipboard operations (getter will return permanent object) */
 	static void*	GetClipboardData(HWND hWnd,
@@ -678,9 +678,9 @@ inline void CFileFind::Close() {
 inline bool CFileFind::Find(const TCHAR* lpszName /* = _T("*.*") */) {
 	Close();
 	assert(lpszName != 0);
-	assert(_tcslen(lpszName) < MAX_PATH);
+	assert(std::_tcslen(lpszName) < MAX_PATH);
 
-	_tcscpy(m_wfd.cFileName, lpszName);
+	std::_tcscpy(m_wfd.cFileName, lpszName);
 	m_hFind = ::FindFirstFile(lpszName, &m_wfd);
 	if(m_hFind == INVALID_HANDLE_VALUE) {
 		m_hFind = 0;
@@ -701,17 +701,15 @@ inline void CFileFind::GetCreationTime(FILETIME& timeStamp) const {
 	timeStamp = m_wfd.ftCreationTime;
 }
 
-inline tstring CFileFind::GetFileName() const {
+inline std::tstring CFileFind::GetFileName() const {
 	assert(m_bFound);
 	return m_wfd.cFileName;
 }
 
-inline tstring CFileFind::GetFilePath() const {
+inline std::tstring CFileFind::GetFilePath() const {
 	assert(m_bFound);
 	TCHAR	szPath[MAX_PATH];
-	if(_tfullpath(szPath, m_wfd.cFileName, MAX_PATH) != 0)
-		return szPath;
-	return _T("");
+	return (_tfullpath(szPath, m_wfd.cFileName, MAX_PATH) != 0) ? szPath : _T("");
 }
 
 inline ULONGLONG CFileFind::GetFileSize() const {
@@ -723,10 +721,10 @@ inline ULONGLONG CFileFind::GetFileSize() const {
 	return size.QuadPart;
 }
 
-inline tstring CFileFind::GetFileTitle() const {
+inline std::tstring CFileFind::GetFileTitle() const {
 	assert(m_bFound);
 
-	const tstring	strName = GetFileName();
+	const std::tstring	strName = GetFileName();
 	if(!strName.empty()) {
 		TCHAR	szTitle[MAX_PATH];
 		_tsplitpath(strName.c_str(), 0, 0, szTitle, 0);
@@ -735,9 +733,9 @@ inline tstring CFileFind::GetFileTitle() const {
 	return _T("");
 }
 
-inline tstring CFileFind::GetFileUrl() const {
+inline std::tstring CFileFind::GetFileUrl() const {
 	assert(m_bFound);
-	const tstring	strPath = GetFilePath();
+	const std::tstring	strPath = GetFilePath();
 	return !strPath.empty() ? (_T("file://") + strPath) : _T("");
 }
 
@@ -751,7 +749,7 @@ inline void CFileFind::GetLastWriteTime(FILETIME& timeStamp) const {
 	timeStamp = m_wfd.ftLastWriteTime;
 }
 
-inline tstring CFileFind::GetRoot() const {
+inline std::tstring CFileFind::GetRoot() const {
 	assert(m_bFound);
 	TCHAR	szPath[MAX_PATH];
 	return (_tfullpath(szPath, m_wfd.cFileName, MAX_PATH) != 0) ? szPath : _T("");
@@ -770,7 +768,7 @@ inline bool CFileFind::IsDirectory() const {
 }
 
 inline bool CFileFind::IsDots() const {
-	return IsDirectory() && (_tcscmp(m_wfd.cFileName, _T(".")) == 0 || _tcscmp(m_wfd.cFileName, _T("..")) == 0);
+	return IsDirectory() && (std::_tcscmp(m_wfd.cFileName, _T(".")) == 0 || std::_tcscmp(m_wfd.cFileName, _T("..")) == 0);
 }
 
 inline bool CFileFind::IsHidden() const {
@@ -818,7 +816,7 @@ inline void* CClipboard::GetClipboardData(HWND hWnd, UINT nFormat, DWORD* pdwSiz
 	pData = malloc(dwSize);
 	if(pData == 0)
 		return ::CloseClipboard, ::GlobalUnlock(hGlobal), 0;
-	memcpy(pData, GlobalLock(hGlobal), dwSize);
+	std::memcpy(pData, GlobalLock(hGlobal), dwSize);
 	::GlobalUnlock(hGlobal);
 	::CloseClipboard();
 
@@ -864,7 +862,7 @@ inline void* CClipboard::GetFirstAvailableClipboardData(
 	return pData;
 }
 
-inline bool CClipboard::ReadClipboardText(HWND hWnd, char* pszText, size_t cch) {
+inline bool CClipboard::ReadClipboardText(HWND hWnd, char* pszText, std::size_t cch) {
 	HGLOBAL	hGlobal;
 	char*	pszString;
 
@@ -876,14 +874,14 @@ inline bool CClipboard::ReadClipboardText(HWND hWnd, char* pszText, size_t cch)
 	if(hGlobal == 0)
 		return ::CloseClipboard(), false;
 	pszString = static_cast<char*>(::GlobalLock(hGlobal));
-	strncpy(pszText, pszString, cch);
+	std::strncpy(pszText, pszString, cch);
 	::GlobalUnlock(hGlobal);
 	::CloseClipboard();
 
 	return true;
 }
 
-inline bool CClipboard::ReadClipboardText(HWND hWnd, wchar_t* pszText, size_t cch) {
+inline bool CClipboard::ReadClipboardText(HWND hWnd, wchar_t* pszText, std::size_t cch) {
 	HGLOBAL		hGlobal;
 	char*		psz = 0;
 	wchar_t*	pwsz = 0;
@@ -894,7 +892,7 @@ inline bool CClipboard::ReadClipboardText(HWND hWnd, wchar_t* pszText, size_t cc
 		if(hGlobal == 0)
 			return ::CloseClipboard(), false;
 		pwsz = static_cast<wchar_t*>(::GlobalLock(hGlobal));
-		wcsncpy(pszText, pwsz, cch);
+		std::wcsncpy(pszText, pwsz, cch);
 	} else if(::IsClipboardFormatAvailable(CF_TEXT)) {
 		::OpenClipboard(hWnd);
 		hGlobal = ::GetClipboardData(CF_TEXT);
@@ -925,7 +923,7 @@ inline bool CClipboard::SetClipboardData(
 	if(hGlobal == 0)
 		return ::CloseClipboard(), false;
 	pTempData = ::GlobalLock(hGlobal);
-	memcpy(pTempData, pData, dwSize);
+	std::memcpy(pTempData, pData, dwSize);
 	::GlobalUnlock(hGlobal);
 	bReturn = (::SetClipboardData(nFormat, hGlobal) != 0);
 	::CloseClipboard();
@@ -933,17 +931,17 @@ inline bool CClipboard::SetClipboardData(
 	return bReturn;
 }
 
-inline bool CClipboard::SetClipboardText(HWND hWnd, const char* pszText, size_t cch /* = -1 */) {
+inline bool CClipboard::SetClipboardText(HWND hWnd, const char* pszText, std::size_t cch /* = -1 */) {
 	HGLOBAL	hGlobal;
 	char*	pszString;
 
 	if(cch == -1)
-		cch = strlen(pszText);
+		cch = std::strlen(pszText);
 	hGlobal = ::GlobalAlloc(GHND, cch + 1);
 	if(hGlobal == 0)
 		return false;
 	pszString = static_cast<char*>(::GlobalLock(hGlobal));
-	strncpy(pszString, pszText, cch);
+	std::strncpy(pszString, pszText, cch);
 	::GlobalUnlock(hGlobal);
 	if(!::OpenClipboard(hWnd)){
 		::GlobalFree(hGlobal);
@@ -956,17 +954,17 @@ inline bool CClipboard::SetClipboardText(HWND hWnd, const char* pszText, size_t
 	return true;
 }
 
-inline bool CClipboard::SetClipboardText(HWND hWnd, const wchar_t* pszText, size_t cch /* = -1 */) {
+inline bool CClipboard::SetClipboardText(HWND hWnd, const wchar_t* pszText, std::size_t cch /* = -1 */) {
 	HGLOBAL		hGlobal;
 	wchar_t*	pwszString;
 
 	if(cch == -1)
-		cch = wcslen(pszText);
+		cch = std::wcslen(pszText);
 	hGlobal = ::GlobalAlloc(GHND, (cch + 1) * 2);
 	if(hGlobal == 0)
 		return false;
 	pwszString = static_cast<wchar_t*>(::GlobalLock(hGlobal));
-	wcsncpy(pwszString, pszText, cch);
+	std::wcsncpy(pwszString, pszText, cch);
 	::GlobalUnlock(hGlobal);
 	if(!::OpenClipboard(hWnd)){
 		::GlobalFree(hGlobal);
